//INIZIO 2_01_015

///////////////////Funzione per il calcolo valorizzazione di magazzino costo medio alla data
IF NOT EXISTS(
        SELECT 1 
        FROM   SYS.SYSPROCEDURE
        WHERE  PROC_NAME = 'fn_esistenza_cm') THEN
		
	CREATE FUNCTION "DBA"."fn_esistenza_cm"(in @id_azienda integer,in @id_articolo integer,in @id_magazzino integer,in @anno integer,in @mese integer,in @ai_id_valuta integer)
	returns char(120)
	begin
	  /*
	  Elisa Moneti
	  16/02/1999

	  Calcolo:
	  .     "Esistenza fisica" in base ai parametri di esistenza specificati
	  nella tabella PAR_ESISTENZA.
	  .     "Esistenza Fiscale" (Carichi - Scarichi)
	  .     "Costo Medio" (Valore Caricato / Quantit- Scaricata)

	  Argomenti input:
	  . ID Esercizio (Obbligatorio)
	  . ID Articolo (Obbligatorio)
	  . ID Magazzino        
	  . Anno                        (Obbligatorio)
	  . Mese                        (Obbligatorio)
	  . ID Valuta

	  Valore di ritorno:
	  . 1+ - 20+    carattere --> Esistenza Fisica
	  . 21+ - 40+ carattere --> Esistenza Fiscale
	  . 41+ - 60+ carattere --> Costo Medio
	  . 61+ - 80  carattere --> Quantita'/Peso Netto -  Caricata
	  . 81+ - 100  carattere --> Quantita'/Peso Netto - Scaricata
	  . 101+ - 120  carattere --> Valore Caricato
	 
	  Elisa Moneti          14/05/1999
	  Modifica: La condizione di ricerca in RIEPILOGO relativa ad anno e mese:
	  . fino all'anno specificato
	  . solamente per l'anno specificato, fino al mese specificato.
	  all'anno specificato 

	  Elisa M.      29/08/2001      BL#15127#
	  Il costo medio deve essere ritornato nella Valuta richiesta.
	  I movimenti registrati nella tabella RIEPILOGO, possono essere di valute diverse 
	  in seguito al passaggio dalle Lire all'Euro; di questo deve essere tenuto conto quando 
	  si fanno operazioni tra i record della tabella RIEPILOGO con Valuta diversa.

	  Il calcolo dell'esistenza, deve essere uguale a quello di FN_ESI_DISP, 
	  dove viene tenuto conto del tipo di movimentazione dell'articolo ( a peso o a quantita'')
	  */
	  declare @cnt_mov_articolo integer;
	  declare @car_fiscali char(1);
	  declare @sca_fiscali char(1);
	  declare @ord_clienti char(1);
	  declare @ord_fornitori char(1);
	  declare @vis_clienti char(1);
	  declare @vis_fornitori char(1);
	  declare @imp_produzione char(1);
	  declare @ord_produzione char(1);
	  declare @cl_clienti char(1);
	  declare @cl_fornitori char(1);
	  declare @gr_lib_1 char(1);
	  declare @gr_lib_2 char(1);
	  declare @gr_lib_3 char(1);
	  declare @gr_lib_4 char(1);
	  declare @lf_esi_fisica float(4);
	  declare @ls_esi_fisica char(20);
	  declare @lf_esi_fiscale float(4);
	  declare @ls_esi_fiscale char(20);
	  declare @lf_costo_medio float(4);
	  declare @ls_costo_medio char(20);
	  declare @lf_val_caricato float(4);
	  declare @ls_val_caricato char(20);
	  declare @lf_qtapeso_caricati float(4);
	  declare @ls_qtapeso_caricati char(20);
	  declare @lf_qtapeso_scaricati float(4);
	  declare @ls_qtapeso_scaricati char(20);
	  declare @li_car_fiscali integer;
	  declare @li_sca_fiscali integer;
	  declare @li_ord_clienti integer;
	  declare @li_ord_fornitori integer;
	  declare @li_vis_clienti integer;
	  declare @li_vis_fornitori integer;
	  declare @li_imp_produzione integer;
	  declare @li_ord_produzione integer;
	  declare @li_cl_clienti integer;
	  declare @li_cl_fornitori integer;
	  declare @li_gr_lib_1 integer;
	  declare @li_gr_lib_2 integer;
	  declare @li_gr_lib_3 integer;
	  declare @li_gr_lib_4 integer;
	  declare @ls_tipo_mov char(1); //BL#15127#
	  declare @ls_return char(120);
	  //
	  //
	  if(@id_articolo<>0) and(not(@id_articolo is null)) then
	    /* Se l'Articolo non e' mai stato movimentato, ritorno NULL */
	    select "count"(*) into @cnt_mov_articolo
	      from riepilogo
	      where id_articolo=@id_articolo;
	    if(@cnt_mov_articolo=0) then
	      set @ls_return=null;
	      return(@ls_return)
	    end if
	  end if
	  ; /* 
	  Recupero i parametri di esistenza
	  */
	  select par_esistenza.car_fiscali,
	    par_esistenza.sca_fiscali,
	    par_esistenza.ord_clienti,
	    par_esistenza.ord_fornitori,
	    par_esistenza.vis_clienti,
	    par_esistenza.vis_fornitori,
	    par_esistenza.imp_produzione,
	    par_esistenza.ord_produzione,
	    par_esistenza.cl_clienti,
	    par_esistenza.cl_fornitori,
	    par_esistenza.gr_lib_1,
	    par_esistenza.gr_lib_2,
	    par_esistenza.gr_lib_3,
	    par_esistenza.gr_lib_4 into @car_fiscali,
	    @sca_fiscali,@ord_clienti,@ord_fornitori,@vis_clienti,
	    @vis_clienti,@imp_produzione,@ord_produzione,@cl_clienti,@cl_fornitori,
	    @gr_lib_1,@gr_lib_2,@gr_lib_3,
	    @gr_lib_4 from par_esistenza;
	  //Carichi fiscali
	  if not(@car_fiscali is null) then
	    if @car_fiscali='+' then
	      set @li_car_fiscali=1
	    else
	      set @li_car_fiscali=-1
	    end if
	  else
	    set @li_car_fiscali=0
	  end if
	  ;
	  // Scarichi fiscali
	  if not(@sca_fiscali is null) then
	    if @sca_fiscali='+' then
	      set @li_sca_fiscali=1
	    else
	      set @li_sca_fiscali=-1
	    end if
	  else
	    set @li_sca_fiscali=0
	  end if
	  ;
	  // Ordinato Clienti
	  if not(@ord_clienti is null) then
	    if @ord_clienti='+' then
	      set @li_ord_clienti=1
	    else
	      set @li_ord_clienti=-1
	    end if
	  else
	    set @li_ord_clienti=0
	  end if
	  ;
	  // ordinato fornitori
	  if not(@ord_fornitori is null) then
	    if @ord_fornitori='+' then
	      set @li_ord_fornitori=1
	    else
	      set @li_ord_fornitori=-1
	    end if
	  else
	    set @li_ord_fornitori=0
	  end if
	  ;
	  // Visione Clienti
	  if not(@vis_clienti is null) then
	    if @vis_clienti='+' then
	      set @li_vis_clienti=1
	    else
	      set @li_vis_clienti=-1
	    end if
	  else
	    set @li_vis_clienti=0
	  end if
	  ;
	  // Visione Fornitori
	  if not(@vis_fornitori is null) then
	    if @vis_fornitori='+' then
	      set @li_vis_fornitori=1
	    else
	      set @li_vis_fornitori=-1
	    end if
	  else
	    set @li_vis_fornitori=0
	  end if
	  ;
	  // Impegnato Produzione
	  if not(@imp_produzione is null) then
	    if @imp_produzione='+' then
	      set @li_imp_produzione=1
	    else
	      set @li_imp_produzione=-1
	    end if
	  else
	    set @li_imp_produzione=0
	  end if
	  ;
	  // Ordinato Produzione
	  if not(@ord_produzione is null) then
	    if @ord_produzione='+' then
	      set @li_ord_produzione=1
	    else
	      set @li_ord_produzione=-1
	    end if
	  else
	    set @li_ord_produzione=0
	  end if
	  ;
	  // Conto Lavorazione Clienti
	  if not(@cl_clienti is null) then
	    if @cl_clienti='+' then
	      set @li_cl_clienti=1
	    else
	      set @li_cl_clienti=-1
	    end if
	  else
	    set @li_cl_clienti=0
	  end if
	  ;
	  // Conto Lavorazione Fornitori
	  if not(@cl_fornitori is null) then
	    if @cl_fornitori='+' then
	      set @li_cl_fornitori=1
	    else
	      set @li_cl_fornitori=-1
	    end if
	  else
	    set @li_cl_fornitori=0
	  end if
	  ;
	  // Gruppo Libero 1
	  if not(@gr_lib_1 is null) then
	    if @gr_lib_1='+' then
	      set @li_gr_lib_1=1
	    else
	      set @li_gr_lib_1=-1
	    end if
	  else
	    set @li_gr_lib_1=0
	  end if
	  ;
	  // Gruppo Libero 2
	  if not(@gr_lib_2 is null) then
	    if @gr_lib_2='+' then
	      set @li_gr_lib_2=1
	    else
	      set @li_gr_lib_2=-1
	    end if
	  else
	    set @li_gr_lib_2=0
	  end if
	  ;
	  // Gruppo Libero 3
	  if not(@gr_lib_3 is null) then
	    if @gr_lib_3='+' then
	      set @li_gr_lib_3=1
	    else
	      set @li_gr_lib_3=-1
	    end if
	  else
	    set @li_gr_lib_3=0
	  end if
	  ;
	  // Gruppo Libero 4
	  if not(@gr_lib_4 is null) then
	    if @gr_lib_4='+' then
	      set @li_gr_lib_4=1
	    else
	      set @li_gr_lib_4=-1
	    end if
	  else
	    set @li_gr_lib_4=0
	  end if
	  ;
	  // BL#15127#i
	  select m.tipo into @ls_tipo_mov
	    from unita_confezione as u,unita_misura as m
	    where u.id_articolo=@id_articolo
	    and u.unita_base='S'
	    and m.id_unita_misura=u.id_unita_misura;
	  //
	  /* Se l'articolo e' movimentato a peso, calcolo i valori di magazzino a Peso*/
	  if(@ls_tipo_mov='P') then
	    if @id_magazzino is null or @id_magazzino=0 then
	      /* 
	      Calcolo a peso su tutti i magazzini
	      */
	      select(IfNull((Sum(Riepilogo.peso_Caricato)*@li_car_fiscali),0,Sum(Riepilogo.peso_Caricato)*@li_car_fiscali)
	        +IfNull((Sum(Riepilogo.peso_Scaricato)*@li_sca_fiscali),0,Sum(Riepilogo.peso_Scaricato)*@li_sca_fiscali)
	        +IfNull((Sum(Riepilogo.peso_Ord_Clienti)*@li_ord_clienti),0,Sum(Riepilogo.peso_Ord_Clienti)*@li_ord_clienti)
	        +IfNull((Sum(Riepilogo.peso_Ord_Fornitori)*@li_ord_fornitori),0,Sum(Riepilogo.peso_Ord_Fornitori)*@li_ord_fornitori)
	        +IfNull((Sum(Riepilogo.peso_Vis_Clienti)*@li_vis_clienti),0,Sum(Riepilogo.peso_Vis_Clienti)*@li_vis_clienti)
	        +IfNull((Sum(Riepilogo.peso_Vis_Fornitori)*@li_vis_fornitori),0,Sum(Riepilogo.peso_Vis_Fornitori)*@li_vis_fornitori)
	        +IfNull((Sum(Riepilogo.peso_Imp_Produzione)*@li_imp_produzione),0,Sum(Riepilogo.peso_Imp_Produzione)*@li_imp_produzione)
	        +IfNull((Sum(Riepilogo.peso_Ord_Produzione)*@li_ord_produzione),0,Sum(Riepilogo.peso_Ord_Produzione)*@li_ord_produzione)
	        +IfNull((Sum(Riepilogo.peso_CL_Clienti)*@li_cl_clienti),0,Sum(Riepilogo.peso_CL_Clienti)*@li_cl_clienti)
	        +IfNull((Sum(Riepilogo.peso_CL_Fornitori)*@li_cl_fornitori),0,Sum(Riepilogo.peso_CL_Fornitori)*@li_cl_fornitori)
	        +IfNull((Sum(Riepilogo.peso_Gruppo_Lib_1)*@li_gr_lib_1),0,Sum(Riepilogo.peso_Gruppo_Lib_1)*@li_gr_lib_1)
	        +IfNull((Sum(Riepilogo.peso_Gruppo_Lib_2)*@li_gr_lib_2),0,Sum(Riepilogo.peso_Gruppo_Lib_2)*@li_gr_lib_2)
	        +IfNull((Sum(Riepilogo.peso_Gruppo_Lib_3)*@li_gr_lib_3),0,Sum(Riepilogo.peso_Gruppo_Lib_3)*@li_gr_lib_3)
	        +IfNull((Sum(Riepilogo.peso_Gruppo_Lib_4)*@li_gr_lib_4),0,Sum(Riepilogo.peso_Gruppo_Lib_4)*@li_gr_lib_4)),
	        //
	        IfNull((Sum(Riepilogo.peso_Caricato)),0,Sum(Riepilogo.peso_Caricato))
	        -IfNull((Sum(Riepilogo.peso_Scaricato)),0,Sum(Riepilogo.peso_Scaricato)),
	        //
	        IfNull((Sum(fn_conv_valuta(riepilogo.id_valuta,Riepilogo.Val_Caricato,@ai_id_valuta))),0,Sum(fn_conv_valuta(riepilogo.id_valuta,Riepilogo.Val_Caricato,@ai_id_valuta))),
	        //
	        IfNull((Sum(Riepilogo.peso_Caricato)),0,Sum(Riepilogo.peso_Caricato)),
	        //
	        IfNull((Sum(Riepilogo.peso_Scaricato)),0,Sum(Riepilogo.peso_Scaricato)) into @lf_esi_fisica,
	        @lf_esi_fiscale,
	        //
	        @lf_Val_caricato,@lf_qtapeso_caricati,
	        @lf_qtapeso_scaricati from riepilogo
	        where riepilogo.id_attivita=(select id_attivita from azienda where id_azienda=@id_azienda)
	        and riepilogo.id_articolo=@id_articolo
	        and(riepilogo.anno<@anno
	        or(riepilogo.anno=@anno
	        and riepilogo.mese<=@mese))
	    else
	      /*
	      Calcolo a peso su un magazzino specifico
	      */
	      select(IfNull((Sum(Riepilogo.peso_Caricato)*@li_car_fiscali),0,Sum(Riepilogo.peso_Caricato)*@li_car_fiscali)
	        +IfNull((Sum(Riepilogo.peso_Scaricato)*@li_sca_fiscali),0,Sum(Riepilogo.peso_Scaricato)*@li_sca_fiscali)
	        +IfNull((Sum(Riepilogo.peso_Ord_Clienti)*@li_ord_clienti),0,Sum(Riepilogo.peso_Ord_Clienti)*@li_ord_clienti)
	        +IfNull((Sum(Riepilogo.peso_Ord_Fornitori)*@li_ord_fornitori),0,Sum(Riepilogo.peso_Ord_Fornitori)*@li_ord_fornitori)
	        +IfNull((Sum(Riepilogo.peso_Vis_Clienti)*@li_vis_clienti),0,Sum(Riepilogo.peso_Vis_Clienti)*@li_vis_clienti)
	        +IfNull((Sum(Riepilogo.peso_Vis_Fornitori)*@li_vis_fornitori),0,Sum(Riepilogo.peso_Vis_Fornitori)*@li_vis_fornitori)
	        +IfNull((Sum(Riepilogo.peso_Imp_Produzione)*@li_imp_produzione),0,Sum(Riepilogo.peso_Imp_Produzione)*@li_imp_produzione)
	        +IfNull((Sum(Riepilogo.peso_Ord_Produzione)*@li_ord_produzione),0,Sum(Riepilogo.peso_Ord_Produzione)*@li_ord_produzione)
	        +IfNull((Sum(Riepilogo.peso_CL_Clienti)*@li_cl_clienti),0,Sum(Riepilogo.peso_CL_Clienti)*@li_cl_clienti)
	        +IfNull((Sum(Riepilogo.peso_CL_Fornitori)*@li_cl_fornitori),0,Sum(Riepilogo.peso_CL_Fornitori)*@li_cl_fornitori)
	        +IfNull((Sum(Riepilogo.peso_Gruppo_Lib_1)*@li_gr_lib_1),0,Sum(Riepilogo.peso_Gruppo_Lib_1)*@li_gr_lib_1)
	        +IfNull((Sum(Riepilogo.peso_Gruppo_Lib_2)*@li_gr_lib_2),0,Sum(Riepilogo.peso_Gruppo_Lib_2)*@li_gr_lib_2)
	        +IfNull((Sum(Riepilogo.peso_Gruppo_Lib_3)*@li_gr_lib_3),0,Sum(Riepilogo.peso_Gruppo_Lib_3)*@li_gr_lib_3)
	        +IfNull((Sum(Riepilogo.peso_Gruppo_Lib_4)*@li_gr_lib_4),0,Sum(Riepilogo.peso_Gruppo_Lib_4)*@li_gr_lib_4)),
	        //
	        IfNull((Sum(Riepilogo.peso_Caricato)),0,Sum(Riepilogo.peso_Caricato))
	        -IfNull((Sum(Riepilogo.peso_Scaricato)),0,Sum(Riepilogo.peso_Scaricato)),
	        //
	        IfNull((Sum(fn_conv_valuta(riepilogo.id_valuta,Riepilogo.Val_Caricato,@ai_id_valuta))),0,Sum(fn_conv_valuta(riepilogo.id_valuta,Riepilogo.Val_Caricato,@ai_id_valuta))),
	        //
	        IfNull((Sum(Riepilogo.peso_Caricato)),0,Sum(Riepilogo.peso_Caricato)),
	        //
	        IfNull((Sum(Riepilogo.peso_Scaricato)),0,Sum(Riepilogo.peso_Scaricato)) into @lf_esi_fisica,
	        @lf_esi_fiscale,
	        //
	        @lf_Val_caricato,@lf_qtapeso_caricati,
	        @lf_qtapeso_scaricati from riepilogo
	        where id_attivita=(select id_attivita from azienda where id_azienda=@id_azienda)
	        and id_articolo=@id_articolo
	        and id_locazione=any(select id_locazione from locazione where id_magazzino=@id_magazzino)
	        and(riepilogo.anno<@anno
	        or(riepilogo.anno=@anno
	        and riepilogo.mese<=@mese))
	    end if
	  else
	    /*
	    Calcolo a Quantita'' su tutti i magazzini
	    */
	    if @id_magazzino is null or @id_magazzino=0 then
	      select(IfNull((Sum(Riepilogo.Qta_Caricata)*@li_car_fiscali),0,Sum(Riepilogo.Qta_Caricata)*@li_car_fiscali)
	        +IfNull((Sum(Riepilogo.Qta_Scaricata)*@li_sca_fiscali),0,Sum(Riepilogo.Qta_Scaricata)*@li_sca_fiscali)
	        +IfNull((Sum(Riepilogo.Qta_Ord_Clienti)*@li_ord_clienti),0,Sum(Riepilogo.Qta_Ord_Clienti)*@li_ord_clienti)
	        +IfNull((Sum(Riepilogo.Qta_Ord_Fornitori)*@li_ord_fornitori),0,Sum(Riepilogo.Qta_Ord_Fornitori)*@li_ord_fornitori)
	        +IfNull((Sum(Riepilogo.Qta_Vis_Clienti)*@li_vis_clienti),0,Sum(Riepilogo.Qta_Vis_Clienti)*@li_vis_clienti)
	        +IfNull((Sum(Riepilogo.Qta_Scaricata)),0,Sum(Riepilogo.Qta_Scaricata))
	        +IfNull((Sum(Riepilogo.Qta_Vis_Fornitori)*@li_vis_fornitori),0,Sum(Riepilogo.Qta_Vis_Fornitori)*@li_vis_fornitori)
	        +IfNull((Sum(Riepilogo.Qta_Imp_Produzione)*@li_imp_produzione),0,Sum(Riepilogo.Qta_Imp_Produzione)*@li_imp_produzione)
	        +IfNull((Sum(Riepilogo.Qta_Ord_Produzione)*@li_ord_produzione),0,Sum(Riepilogo.Qta_Ord_Produzione)*@li_ord_produzione)
	        +IfNull((Sum(Riepilogo.Qta_CL_Clienti)*@li_cl_clienti),0,Sum(Riepilogo.Qta_CL_Clienti)*@li_cl_clienti)
	        +IfNull((Sum(Riepilogo.Qta_CL_Fornitori)*@li_cl_fornitori),0,Sum(Riepilogo.Qta_CL_Fornitori)*@li_cl_fornitori)
	        +IfNull((Sum(Riepilogo.Qta_Gruppo_Lib_1)*@li_gr_lib_1),0,Sum(Riepilogo.Qta_Gruppo_Lib_1)*@li_gr_lib_1)
	        +IfNull((Sum(Riepilogo.Qta_Gruppo_Lib_2)*@li_gr_lib_2),0,Sum(Riepilogo.Qta_Gruppo_Lib_2)*@li_gr_lib_2)
	        +IfNull((Sum(Riepilogo.Qta_Gruppo_Lib_3)*@li_gr_lib_3),0,Sum(Riepilogo.Qta_Gruppo_Lib_3)*@li_gr_lib_3)
	        +IfNull((Sum(Riepilogo.Qta_Gruppo_Lib_4)*@li_gr_lib_4),0,Sum(Riepilogo.Qta_Gruppo_Lib_4)*@li_gr_lib_4)),
	        //
	        IfNull((Sum(Riepilogo.Qta_Caricata)),0,Sum(Riepilogo.Qta_Caricata))
	        -IfNull((Sum(Riepilogo.Qta_Scaricata)),0,Sum(Riepilogo.Qta_Scaricata)),
	        //
	        IfNull((Sum(fn_conv_valuta(riepilogo.id_valuta,Riepilogo.Val_Caricato,@ai_id_valuta))),0,Sum(fn_conv_valuta(riepilogo.id_valuta,Riepilogo.Val_Caricato,@ai_id_valuta))),
	        //
	        IfNull((Sum(Riepilogo.Qta_Caricata)*@li_car_fiscali),0,Sum(Riepilogo.Qta_Caricata)),
	        //
	        IfNull((Sum(Riepilogo.Qta_Scaricata)*@li_car_fiscali),0,Sum(Riepilogo.Qta_Scaricata)) into @lf_esi_fisica,
	        @lf_esi_fiscale,
	        //
	        @lf_Val_caricato,@lf_qtapeso_caricati,
	        @lf_qtapeso_scaricati from riepilogo
	        where riepilogo.id_attivita=(select id_attivita from azienda where id_azienda=@id_azienda)
	        and riepilogo.id_articolo=@id_articolo
	        and(riepilogo.anno<@anno
	        or(riepilogo.anno=@anno
	        and riepilogo.mese<=@mese))
	    else
	      //
	      /*
	      Calcolo a Quantita'' su un magazzino specifico
	      */
	      select(IfNull((Sum(Riepilogo.Qta_Caricata)*@li_car_fiscali),0,Sum(Riepilogo.Qta_Caricata)*@li_car_fiscali)
	        +IfNull((Sum(Riepilogo.Qta_Scaricata)*@li_sca_fiscali),0,Sum(Riepilogo.Qta_Scaricata)*@li_sca_fiscali)
	        +IfNull((Sum(Riepilogo.Qta_Ord_Clienti)*@li_ord_clienti),0,Sum(Riepilogo.Qta_Ord_Clienti)*@li_ord_clienti)
	        +IfNull((Sum(Riepilogo.Qta_Ord_Fornitori)*@li_ord_fornitori),0,Sum(Riepilogo.Qta_Ord_Fornitori)*@li_ord_fornitori)
	        +IfNull((Sum(Riepilogo.Qta_Vis_Clienti)*@li_vis_clienti),0,Sum(Riepilogo.Qta_Vis_Clienti)*@li_vis_clienti)
	        +IfNull((Sum(Riepilogo.Qta_Scaricata)),0,Sum(Riepilogo.Qta_Scaricata))
	        +IfNull((Sum(Riepilogo.Qta_Vis_Fornitori)*@li_vis_fornitori),0,Sum(Riepilogo.Qta_Vis_Fornitori)*@li_vis_fornitori)
	        +IfNull((Sum(Riepilogo.Qta_Imp_Produzione)*@li_imp_produzione),0,Sum(Riepilogo.Qta_Imp_Produzione)*@li_imp_produzione)
	        +IfNull((Sum(Riepilogo.Qta_Ord_Produzione)*@li_ord_produzione),0,Sum(Riepilogo.Qta_Ord_Produzione)*@li_ord_produzione)
	        +IfNull((Sum(Riepilogo.Qta_CL_Clienti)*@li_cl_clienti),0,Sum(Riepilogo.Qta_CL_Clienti)*@li_cl_clienti)
	        +IfNull((Sum(Riepilogo.Qta_CL_Fornitori)*@li_cl_fornitori),0,Sum(Riepilogo.Qta_CL_Fornitori)*@li_cl_fornitori)
	        +IfNull((Sum(Riepilogo.Qta_Gruppo_Lib_1)*@li_gr_lib_1),0,Sum(Riepilogo.Qta_Gruppo_Lib_1)*@li_gr_lib_1)
	        +IfNull((Sum(Riepilogo.Qta_Gruppo_Lib_2)*@li_gr_lib_2),0,Sum(Riepilogo.Qta_Gruppo_Lib_2)*@li_gr_lib_2)
	        +IfNull((Sum(Riepilogo.Qta_Gruppo_Lib_3)*@li_gr_lib_3),0,Sum(Riepilogo.Qta_Gruppo_Lib_3)*@li_gr_lib_3)
	        +IfNull((Sum(Riepilogo.Qta_Gruppo_Lib_4)*@li_gr_lib_4),0,Sum(Riepilogo.Qta_Gruppo_Lib_4)*@li_gr_lib_4)),
	        //
	        IfNull((Sum(Riepilogo.Qta_Caricata)),0,Sum(Riepilogo.Qta_Caricata))
	        -IfNull((Sum(Riepilogo.Qta_Scaricata)),0,Sum(Riepilogo.Qta_Scaricata)),
	        //
	        IfNull((Sum(fn_conv_valuta(riepilogo.id_valuta,Riepilogo.Val_Caricato,@ai_id_valuta))),0,Sum(fn_conv_valuta(riepilogo.id_valuta,Riepilogo.Val_Caricato,@ai_id_valuta))),
	        //
	        IfNull((Sum(Riepilogo.Qta_Caricata)*@li_car_fiscali),0,Sum(Riepilogo.Qta_Caricata)),
	        //
	        IfNull((Sum(Riepilogo.Qta_Scaricata)*@li_car_fiscali),0,Sum(Riepilogo.Qta_Scaricata)) into @lf_esi_fisica,
	        @lf_esi_fiscale,
	        //
	        @lf_Val_caricato,@lf_qtapeso_caricati,
	        @lf_qtapeso_scaricati from riepilogo
	        where id_attivita=(select id_attivita from azienda where id_azienda=@id_azienda)
	        and id_articolo=@id_articolo
	        and id_locazione=any(select id_locazione from locazione where id_magazzino=@id_magazzino)
	        and(riepilogo.anno<@anno
	        or(riepilogo.anno=@anno
	        and riepilogo.mese<=@mese))
	    end if
	  end if
	  ;
	  // BL#15127#f  
	  //
	  //
	  //
	  if(@lf_qtapeso_caricati=0) then
	    set @lf_costo_medio=@lf_val_caricato
	  else
	    set @lf_costo_medio=@lf_val_caricato/@lf_qtapeso_caricati
	  end if
	  ;
	  /* 
	  Costruisco ls stringa di ritorno 
	  */
	  message ' VAL CARICATO:'+STRING(@lf_val_caricato);
	  message ' QTA CARICATA:'+STRING(@lf_qtapeso_caricati);
	  /* Esistenza Fisica */
	  set @ls_esi_fisica=REPEAT(' ',20-LENGTH(STRING(@lf_esi_fisica)))+STRING(@lf_esi_fisica);
	  /* Esistenza Fiscale */
	  set @ls_esi_fiscale=REPEAT(' ',20-LENGTH(STRING(@lf_esi_fiscale)))+STRING(@lf_esi_fiscale);
	  /* Costo Medio */
	  set @ls_costo_medio=REPEAT(' ',20-LENGTH(STRING(@lf_costo_medio)))+STRING(@lf_costo_medio);
	  /* Quantita'' caricata */
	  set @ls_qtapeso_caricati=REPEAT(' ',20-LENGTH(STRING(@lf_qtapeso_caricati)))+STRING(@lf_qtapeso_caricati);
	  /* Quantita'' Scaricata */
	  set @ls_qtapeso_scaricati=REPEAT(' ',20-LENGTH(STRING(@lf_qtapeso_scaricati)))+STRING(@lf_qtapeso_scaricati);
	  /* Valore caricato */
	  set @ls_val_caricato=REPEAT(' ',20-LENGTH(STRING(@lf_val_caricato)))+STRING(@lf_val_caricato);

	  set @ls_return=STRING(@ls_esi_fisica,@ls_esi_fiscale,@ls_costo_medio,@ls_qtapeso_caricati,@ls_qtapeso_scaricati, @ls_val_caricato);
	  return(@ls_return) /* return name */
	end		;
		
END IF;		
////////////////////////////////////////////////////////////////////////////////////////////

/////CCT
IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'cct_sogcom'
        AND      CNAME = 'iobsoleto' )) THEN 
        
		alter table cct_sogcom add iobsoleto integer DEFAULT 0 ;
end if; 

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'cct_sogcom'
        AND      CNAME = 'provincia' )) THEN 
        
		alter table cct_sogcom add provincia char(5) DEFAULT NULL ;
end if; 
////////////////////



IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'sys_modulo'
        AND      CNAME = 'allegati_documenti' )) THEN 
		
	ALTER TABLE sys_modulo ADD allegati_documenti char(1) DEFAULT NULL;
end if;



IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSTABLE
        WHERE  TABLE_NAME = 'riga_documento_prev')) THEN

	CREATE TABLE "dba"."riga_documento_prev" ("id_riga_documento_prev" integer NOT NULL DEFAULT autoincrement, "id_riga_documento" integer NOT NULL DEFAULT NULL, "mostra_immagine" char(1) NOT NULL DEFAULT 'N', "riga_alternativa" char(1) NOT NULL DEFAULT 'N' , PRIMARY KEY ("id_riga_documento_prev") , FOREIGN KEY "fk_riga_documento_prev" ("id_riga_documento" ) REFERENCES "dba"."riga_documento" ON DELETE CASCADE ) ;
	CREATE UNIQUE INDEX "xk_riga_prev_1" ON "dba"."riga_documento_prev" ("id_riga_documento" ) ;
	CREATE TABLE "dba"."documento_allegati" ("id_documento_allegati" integer NOT NULL DEFAULT autoincrement, "id_documento" integer NOT NULL DEFAULT NULL, "num_all" integer NOT NULL DEFAULT NULL, "des_allegato" char(80) DEFAULT NULL, "file_allegato" long varchar DEFAULT NULL , PRIMARY KEY ("id_documento_allegati") , FOREIGN KEY "fk_documento_allegati" ("id_documento" ) REFERENCES "dba"."documento" ON DELETE CASCADE ) ;
	CREATE UNIQUE INDEX "xk_doc_all_1" ON "dba"."documento_allegati" ("id_documento" , "num_all" ) ;	

end if;


//liquidazione
if (SELECT codice FROM   AZIENDA)<>'BEAUTY' then
   alter VIEW ws_liquidazione_iva (id_esercizio,id_attivita,tipo_registro,data_comp_liq_iva,id_reg_pd,segno_reg_iva,imponibile,imposta,id_tab_iva,codice,des_breve,tipo_iva,per_aliquota,per_detrazione,per_ventilazione,ges_plafond,usa_prorata,ges_sco_giornaliero,st_liquidazione,st_reg_iva,st_reg_iva_regpd,ges_beni_strumentali,ges_beni_rivendita,id_registro,descrizione,id_mod_registro) 
	AS select esercizio.id_esercizio,attivita.id_attivita,registro.tipo_registro,reg_pd.data_comp_liq_iva,reg_pd.id_reg_pd,reg_pd.segno_reg_iva,mov_iva.imponibile,mov_iva.imposta,mov_iva.id_tab_iva,tab_iva.codice,tab_iva.des_breve,tab_iva.tipo_iva,tab_iva.per_aliquota,tab_iva.per_detrazione,tab_iva.per_ventilazione,tab_iva.ges_plafond,registro.usa_prorata,registro.ges_sco_giornaliero,
	reg_pd.st_liquidazione,mov_iva.st_reg_iva,reg_pd.st_reg_iva as st_reg_iva_regpd,
	tab_iva.ges_beni_strumentali,tab_iva.ges_beni_rivendita,registro.id_registro,registro.descrizione,mod_registro.id_mod_registro 
	from dba.attivita,dba.esercizio,dba.mov_iva,dba.reg_pd,dba.registro,dba.tab_iva,dba.mod_registro
	where(reg_pd.id_reg_pd = mov_iva.id_reg_pd) and(registro.id_registro = reg_pd.id_registro)
	and(registro.id_esercizio = esercizio.id_esercizio) and(registro.id_attivita = attivita.id_attivita) and(registro.id_mod_registro = mod_registro.id_mod_registro) and(tab_iva.id_tab_iva = mov_iva.id_tab_iva) and((registro.tipo_registro = 'IA') or(registro.tipo_registro = 'IC') or(registro.tipo_registro = 'IV'));
	
end if;

////Gestione Vendite Datalogic Skorpio
IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSTABLE
        WHERE  TABLE_NAME = 'sk_contatori')) THEN
		
		CREATE TABLE "dba"."sk_contatori" ("id_sk_contatori" integer NOT NULL DEFAULT autoincrement, 
		"ordini" integer DEFAULT NULL, 
		"ddt" integer DEFAULT NULL, 
		"scontrini" integer DEFAULT NULL, 
		"resi" integer DEFAULT NULL , 
		PRIMARY KEY ("id_sk_contatori")) ;		
		
end if;		

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSTABLE
        WHERE  TABLE_NAME = 'sk_articoli')) THEN
		
CREATE TABLE "dba"."sk_articoli" ("id_sk_articoli" integer NOT NULL DEFAULT autoincrement, "barcode" char(24) NOT NULL, "codice" char(32) NOT NULL, "descrizione" char(50) DEFAULT NULL, "codiva" char(10) DEFAULT NULL, "giacenza" decimal(18,4) DEFAULT NULL, "molteplicita" integer DEFAULT NULL, "um" char(5) DEFAULT NULL, "id_utente" integer NOT NULL DEFAULT NULL, "id_uc" integer DEFAULT NULL, "corsia" char(8) DEFAULT NULL, "scaffale" char(10) DEFAULT NULL, "ripiano" char(10) DEFAULT NULL, "posizione" char(10) DEFAULT NULL , PRIMARY KEY ("id_sk_articoli")) ;
CREATE UNIQUE INDEX "ix_sk_articoli_1" ON "dba"."sk_articoli" ("barcode" , "codice" , "id_utente" ) ;
end if;		

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSTABLE
        WHERE  TABLE_NAME = 'sk_clienti')) THEN
		
CREATE TABLE "dba"."sk_clienti" ("id_sk_clienti" integer NOT NULL DEFAULT autoincrement, "codice" char(8) NOT NULL DEFAULT NULL, "descrizione" char(50) DEFAULT NULL, "indirizzo" char(50) DEFAULT NULL, "localita" char(50) DEFAULT NULL, "piva" char(11) DEFAULT NULL, "codfisc" char(16) DEFAULT NULL, "codlis" char(8) DEFAULT NULL, "id_utente" integer NOT NULL DEFAULT NULL, "codpagam" char(8) DEFAULT NULL, "iban" char(20) DEFAULT NULL, "tel" char(80) DEFAULT NULL, "mail" char(80) DEFAULT NULL, "note_cli" char(256) DEFAULT NULL , PRIMARY KEY ("id_sk_clienti")) ;
CREATE UNIQUE INDEX "ix_sk_clienti_1" ON "dba"."sk_clienti" ("codice" , "id_utente" ) ;
end if;	

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSTABLE
        WHERE  TABLE_NAME = 'sk_listini')) THEN
		
CREATE TABLE "dba"."sk_listini" ("id_sk_listini" integer NOT NULL DEFAULT autoincrement, "codice" char(8) NOT NULL DEFAULT NULL, "descrizione" char(30) DEFAULT NULL, "codart" char(32) NOT NULL DEFAULT NULL, "prezzo" decimal(18,4) DEFAULT NULL, "id_utente" integer NOT NULL DEFAULT NULL, "barcode" char(24) NOT NULL DEFAULT NULL , PRIMARY KEY ("id_sk_listini")) ;
CREATE UNIQUE INDEX "ix_sk_listini_1" ON "dba"."sk_listini" ("codice" , "barcode" , "codart" , "id_utente" ) ;

end if;	

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSTABLE
        WHERE  TABLE_NAME = 'sk_iva')) THEN
		
CREATE TABLE "dba"."sk_iva" ("id_sk_iva" integer NOT NULL DEFAULT autoincrement, "codice" char(8) NOT NULL DEFAULT NULL, "descrizione" char(30) DEFAULT NULL, "aliquota" decimal(5,2) DEFAULT NULL, "id_utente" integer NOT NULL DEFAULT NULL , PRIMARY KEY ("id_sk_iva")) ;
CREATE UNIQUE INDEX "ix_sk_iva_1" ON "dba"."sk_iva" ("codice" , "id_utente" ) ;
end if;

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSTABLE
        WHERE  TABLE_NAME = 'sk_tesdoc')) THEN
		
CREATE TABLE "dba"."sk_tesdoc" ("id_sk_tesdoc" integer NOT NULL DEFAULT autoincrement, "tipo" char(1) NOT NULL DEFAULT NULL, "numdoc" integer NOT NULL DEFAULT NULL, "datadoc" char(10) NOT NULL DEFAULT NULL, "codcli" char(8) DEFAULT NULL, "dest" char(8) DEFAULT NULL, "totdoc" decimal(18,4) DEFAULT NULL, "id_utente" integer NOT NULL DEFAULT NULL, "totmer" numeric(18,4) DEFAULT NULL, "totiva" numeric(18,4) DEFAULT NULL, "ragcli" char(50) DEFAULT NULL, "codlis" char(8) DEFAULT NULL, "codpagam" char(8) DEFAULT NULL , PRIMARY KEY ("id_sk_tesdoc")) ;
CREATE UNIQUE INDEX "ix_sk_tesdoc_1" ON "dba"."sk_tesdoc" ("tipo" , "datadoc" , "numdoc" , "id_utente" ) ;

end if;

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSTABLE
        WHERE  TABLE_NAME = 'sk_rigdoc')) THEN
		
		CREATE TABLE "dba"."sk_rigdoc" ("id_sk_rigdoc" integer NOT NULL DEFAULT autoincrement, 
		"tipo" char(1) DEFAULT NULL, 
		"numdoc" integer DEFAULT NULL, 
		"datadoc" date DEFAULT NULL, 
		"codart" char(32) DEFAULT NULL, 
		"barcode" char(24) DEFAULT NULL, 
		"qta" decimal(18,4) DEFAULT NULL, 
		"prezzo" decimal(18,4) DEFAULT NULL, 
		"sconto" decimal(5,2) DEFAULT NULL, 
		"impnetto" decimal(18,4) DEFAULT NULL, 
		"impiva" decimal(18,4) DEFAULT NULL , 
		PRIMARY KEY ("id_sk_rigdoc")) ;
		CREATE INDEX "ix_sk_rigdoc_1" ON "dba"."sk_rigdoc" ("tipo" , "datadoc" , "numdoc" , "codart" ) ;
end if;

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSTABLE
        WHERE  TABLE_NAME = 'sk_destinazioni')) THEN
		
CREATE TABLE "dba"."sk_destinazioni" ("id_sk_destinazioni" integer NOT NULL DEFAULT autoincrement, "codice" char(8) NOT NULL DEFAULT NULL, "codcli" char(8) NOT NULL DEFAULT NULL, "descrizione" char(50) DEFAULT NULL, "localita" char(50) DEFAULT NULL, "id_utente" integer NOT NULL DEFAULT NULL , PRIMARY KEY ("id_sk_destinazioni")) ;
CREATE UNIQUE INDEX "ix_sk_destinazioni_1" ON "dba"."sk_destinazioni" ("codice" , "codcli" , "id_utente" ) ;

end if;

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSTABLE
        WHERE  TABLE_NAME = 'sk_giacenze')) THEN
		
CREATE TABLE "dba"."sk_giacenze" ("id_sk_giacenze" integer NOT NULL DEFAULT autoincrement, "codart" char(32) NOT NULL DEFAULT NULL, "giacenza" decimal(18,4) DEFAULT NULL, "um" char(5) DEFAULT NULL, "id_utente" integer NOT NULL DEFAULT NULL , PRIMARY KEY ("id_sk_giacenze")) ;
CREATE UNIQUE INDEX "ix_sk_giacenze_1" ON "dba"."sk_giacenze" ("codart" , "id_utente" ) ;
end if;		
////////////////////////////////////////

/////CCT
IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'cct_par_sistema'
        AND      CNAME = 'id_sottomastro2' )) THEN 
        
		alter table cct_par_sistema add id_sottomastro2 integer DEFAULT NULL ;
end if; 
////////////////////

/////////DAMAZ (aggiornamento triggers var_con_lis_articolo)
IF (EXISTS(SELECT 1 FROM   SYS.SYSTRIGGERS
        WHERE  TRIGNAME = 't_var_con_lis_articolo_bi')) THEN
		
		ALTER TRIGGER "t_var_con_lis_articolo_bi" before insert order 1
			on "DBA".var_con_lis_articolo
			referencing new as inserted
			for each row
			begin
			  /* 
			  Elisa M.     20/12/00   BL#10276# 
			  Calcolo e assegno la priorita'' della condizione in inserimento del record.
			  #BL10277#
			  Ho aggiunto la categoria merceologica come parametro.
			  */
			 declare @li_id_con_lis_articolo integer;
			 declare @ls_var1 long varchar;
			 declare @ls_var2 long varchar;
			 declare @ls_var3 long varchar;
			 if inserted.id_art_var1 is null then 
			    set @ls_var1='N'
			 else
			    set @ls_var1=string(inserted.id_art_var1)
			 end if;
			 if inserted.id_art_var2 is null then 
			    set @ls_var2='N'
			 else
			    set @ls_var2=string(inserted.id_art_var2)
			 end if;
			 if inserted.id_art_var3 is null then 
			    set @ls_var3='N'
			 else
			    set @ls_var3=string(inserted.id_art_var3)
			 end if;
			 SET inserted.pk_codice=@ls_var1+'@'+@ls_var2+'@'+@ls_var3;

			 
			 set @li_id_con_lis_articolo=0;
			 select id_var_con_lis_articolo into @li_id_con_lis_articolo
			 from var_con_lis_articolo
			    where ifnull(id_destinazione,0,id_destinazione)=ifnull(inserted.id_destinazione,0,inserted.id_destinazione)
			    and ifnull(id_sog_commerciale,0,id_sog_commerciale)=ifnull(inserted.id_sog_commerciale,0,inserted.id_sog_commerciale)
			    and ifnull(id_cat_com_sc,0,id_cat_com_sc)=ifnull(inserted.id_cat_com_sc,0,inserted.id_cat_com_sc)
			    and ifnull(id_unita_confezione,0,id_unita_confezione)=ifnull(inserted.id_unita_confezione,0,inserted.id_unita_confezione)
			    and ifnull(id_articolo,0,id_articolo)=ifnull(inserted.id_articolo,0,inserted.id_articolo)
			    and ifnull(id_cat_com_articolo,0,id_cat_com_articolo)=ifnull(inserted.id_cat_com_articolo,0,inserted.id_cat_com_articolo)
			    and ifnull(id_cat_merceologica,0,id_cat_merceologica)=ifnull(inserted.id_cat_merceologica,0,inserted.id_cat_merceologica)
			    and ifnull(data_inizio,cast('2999-01-01' as date),data_inizio)=ifnull(inserted.data_inizio,cast('2999-01-01' as date),inserted.data_inizio)
			    and ifnull(data_fine,cast('2999-01-01' as date),data_fine)=ifnull(inserted.data_fine,cast('2999-01-01' as date),inserted.data_fine)
			    and ifnull(id_sog_commerciale_fornitore,0,id_sog_commerciale_fornitore)=ifnull(inserted.id_sog_commerciale_fornitore,0,inserted.id_sog_commerciale_fornitore)
			    and ifnull(id_anagrafica,0,id_anagrafica)=ifnull(inserted.id_anagrafica,0,inserted.id_anagrafica)
			    and ifnull(qta_minima,0,qta_minima)=ifnull(inserted.qta_minima,0,inserted.qta_minima)
			    and ifnull(qta_massima,0,qta_massima)=ifnull(inserted.qta_massima,0,inserted.qta_massima)
			    and ifnull(applicazione,'',applicazione)=ifnull(inserted.applicazione,'',inserted.applicazione)
			    and ifnull(tipo_applicazione,'',tipo_applicazione)=ifnull(inserted.tipo_applicazione,'',inserted.tipo_applicazione)
			    and ifnull(id_art_var1,'',id_art_var1)=ifnull(inserted.id_art_var1,'',inserted.id_art_var1)
			    and ifnull(id_art_var2,'',id_art_var2)=ifnull(inserted.id_art_var2,'',inserted.id_art_var2)
			    and ifnull(id_art_var3,'',id_art_var3)=ifnull(inserted.id_art_var3,'',inserted.id_art_var3);
			  message 'Condizione di listino: ',@li_id_con_lis_articolo;
			  if @li_id_con_lis_articolo>0 then
			    message 'Condizione di listino gia'' esistente: ',@li_id_con_lis_articolo,'  ',inserted.id_var_con_lis_articolo;
			    raiserror 99999 'Condizione di listino gia'' esistente ...'+string(@li_id_con_lis_articolo)+'  '+string(inserted.id_var_con_lis_articolo);
			    rollback work
			  else
			    set inserted.priorita=cast((fn_calc_priorita_con_listino(inserted.id_destinazione,inserted.id_sog_commerciale,inserted.id_cat_com_sc,inserted.id_unita_confezione,inserted.id_articolo,inserted.id_articolo,inserted.id_cat_com_articolo,inserted.id_cat_merceologica,inserted.id_sog_commerciale_fornitore,inserted.id_anagrafica,inserted.data_inizio,inserted.data_fine,inserted.qta_minima,inserted.qta_massima,inserted.tras_mezzo,inserted.id_tipo_trasporto)) as decimal(18))
			  end if
			end;
end if;

IF (EXISTS(SELECT 1 FROM   SYS.SYSTRIGGERS
        WHERE  TRIGNAME = 't_var_con_lis_articolo_bu')) THEN
		
		ALTER TRIGGER "t_var_con_lis_articolo_bu" before update order 2
		on "DBA".var_con_lis_articolo
		referencing old as deleted new as inserted
		for each row
		begin
		  /*
		  Elisa M.     20/12/00   BL#10276#
		  Calcolo e assegno la priorita'' della condizione in modifica.
		  #BL10277#
		  Ho aggiunto la categoria merceologica come parametro.
		  */
		  declare @li_id_con_lis_articolo integer;
		  declare @ls_var1 long varchar;
		  declare @ls_var2 long varchar;
		  declare @ls_var3 long varchar;
		  if inserted.id_art_var1 is null then 
		     set @ls_var1='N'
		  else
		     set @ls_var1=string(inserted.id_art_var1)
		  end if;
		  if inserted.id_art_var2 is null then 
		      set @ls_var2='N'
		  else
		      set @ls_var2=string(inserted.id_art_var2)
		  end if;
		  if inserted.id_art_var3 is null then 
		      set @ls_var3='N'
		  else
		      set @ls_var3=string(inserted.id_art_var3)
		  end if;
		  SET inserted.pk_codice=@ls_var1+'@'+@ls_var2+'@'+@ls_var3;
		
		  set @li_id_con_lis_articolo=0;
		  select id_var_con_lis_articolo into @li_id_con_lis_articolo
		    from var_con_lis_articolo
		    where ifnull(id_destinazione,0,id_destinazione)=ifnull(inserted.id_destinazione,0,inserted.id_destinazione)
		    and ifnull(id_sog_commerciale,0,id_sog_commerciale)=ifnull(inserted.id_sog_commerciale,0,inserted.id_sog_commerciale)
		    and ifnull(id_cat_com_sc,0,id_cat_com_sc)=ifnull(inserted.id_cat_com_sc,0,inserted.id_cat_com_sc)
		    and ifnull(id_unita_confezione,0,id_unita_confezione)=ifnull(inserted.id_unita_confezione,0,inserted.id_unita_confezione)
		    and ifnull(id_articolo,0,id_articolo)=ifnull(inserted.id_articolo,0,inserted.id_articolo)
		    and ifnull(id_cat_com_articolo,0,id_cat_com_articolo)=ifnull(inserted.id_cat_com_articolo,0,inserted.id_cat_com_articolo)
		    and ifnull(id_cat_merceologica,0,id_cat_merceologica)=ifnull(inserted.id_cat_merceologica,0,inserted.id_cat_merceologica)
		    and ifnull(data_inizio,cast('2999-01-01' as date),data_inizio)=ifnull(inserted.data_inizio,cast('2999-01-01' as date),inserted.data_inizio)
		    and ifnull(data_fine,cast('2999-01-01' as date),data_fine)=ifnull(inserted.data_fine,cast('2999-01-01' as date),inserted.data_fine)
		    and ifnull(id_sog_commerciale_fornitore,0,id_sog_commerciale_fornitore)=ifnull(inserted.id_sog_commerciale_fornitore,0,inserted.id_sog_commerciale_fornitore)
		    and ifnull(id_anagrafica,0,id_anagrafica)=ifnull(inserted.id_anagrafica,0,inserted.id_anagrafica)
		    and ifnull(qta_minima,0,qta_minima)=ifnull(inserted.qta_minima,0,inserted.qta_minima)
		    and ifnull(qta_massima,0,qta_massima)=ifnull(inserted.qta_massima,0,inserted.qta_massima)
		    and ifnull(applicazione,'',applicazione)=ifnull(inserted.applicazione,'',inserted.applicazione)
		    and ifnull(tipo_applicazione,'',tipo_applicazione)=ifnull(inserted.tipo_applicazione,'',inserted.tipo_applicazione)
		    and ifnull(id_art_var1,'',id_art_var1)=ifnull(inserted.id_art_var1,'',inserted.id_art_var1)
		    and ifnull(id_art_var2,'',id_art_var2)=ifnull(inserted.id_art_var2,'',inserted.id_art_var2)
		    and ifnull(id_art_var3,'',id_art_var3)=ifnull(inserted.id_art_var3,'',inserted.id_art_var3)
		    and id_var_con_lis_articolo<>inserted.id_var_con_lis_articolo;
		  if @li_id_con_lis_articolo>0 then
		    message 'Condizione di listino gia'' esistente: ',@li_id_con_lis_articolo,inserted.id_var_con_lis_articolo;
		    raiserror 99999 'Condizione di listino gia'' esistente ...'+string(@li_id_con_lis_articolo)+' '+string(inserted.id_var_con_lis_articolo);
		    rollback work
		  else
		    set inserted.priorita=cast((fn_calc_priorita_con_listino(inserted.id_destinazione,inserted.id_sog_commerciale,inserted.id_cat_com_sc,inserted.id_unita_confezione,inserted.id_articolo,inserted.id_articolo,inserted.id_cat_com_articolo,inserted.id_cat_merceologica,inserted.id_sog_commerciale_fornitore,inserted.id_anagrafica,inserted.data_inizio,inserted.data_fine,inserted.qta_minima,inserted.qta_massima,inserted.tras_mezzo,inserted.id_tipo_trasporto)) as decimal(18))
		  end if
		end;

end if;
/////////////////////////////


/////CCT
IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'FAT_PARAMETRICO'
        AND      CNAME = 'ORIGINE' )) THEN 
        
	ALTER TABLE FAT_PARAMETRICO ADD ORIGINE CHAR(40);
end if; 



/////DERIVAZIONE NUOVA
IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'par_sistema'
        AND      CNAME = 'new_deriv_cl' )) THEN 
        
	alter table par_sistema add new_deriv_cl char(1) DEFAULT 'N';
	update par_sistema set new_deriv_cl='N';
end if; 

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'fat_parametrico'
        AND      CNAME = 'dim_l' )) THEN 

	alter table  fat_parametrico add dim_l numeric(18,4);
end if; 


/////PRIORITA ALIQUOTA IVA
IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'par_sistema'
        AND      CNAME = 'priorita_tab_iva_art' )) THEN 
        
	alter table par_sistema add priorita_tab_iva_art char(1) DEFAULT 'N';
	update par_sistema set priorita_tab_iva_art='N';
end if; 

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'par_sistema'
        AND      CNAME = 'priorita_iva_sosp' )) THEN 
        
	alter table par_sistema add priorita_iva_sosp char(1) DEFAULT 'N';
	update par_sistema set priorita_iva_sosp='N';
end if; 


//Gestione vendite Datalogic Skorpio
IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'sk_articoli'
        AND      CNAME = 'id_utente' )) THEN 
        
		alter table sk_articoli add id_utente integer DEFAULT NULL ;
end if; 

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'sk_articoli'
        AND      CNAME = 'id_uc' )) THEN 
        
		alter table sk_articoli add "id_uc" integer DEFAULT NULL;
end if; 

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'sk_clienti'
        AND      CNAME = 'id_utente' )) THEN 
        
		alter table sk_clienti add id_utente integer DEFAULT NULL ;
end if; 

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'sk_contatori'
        AND      CNAME = 'id_utente' )) THEN 
        
		alter table sk_contatori add id_utente integer DEFAULT NULL ;
end if; 

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'sk_destinazioni'
        AND      CNAME = 'id_utente' )) THEN 
        
		alter table sk_destinazioni add id_utente integer DEFAULT NULL ;
end if; 

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'sk_iva'
        AND      CNAME = 'id_utente' )) THEN 
        
		alter table sk_iva add id_utente integer DEFAULT NULL ;
end if;

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'sk_listini'
        AND      CNAME = 'id_utente' )) THEN 
        
		alter table sk_listini add id_utente integer DEFAULT NULL ;
end if;

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'sk_listini'
        AND      CNAME = 'barcode' )) THEN 
        
		alter table sk_listini add "barcode" char(24) DEFAULT NULL ;
end if;

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'sk_tesdoc'
        AND      CNAME = 'id_utente' )) THEN 
        
		alter table sk_tesdoc add id_utente integer DEFAULT NULL ;
end if;

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'sk_tesdoc'
        AND      CNAME = 'totmer' )) THEN 
        
		alter table sk_tesdoc add totmer numeric(18,4) DEFAULT NULL ;
end if;

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'sk_tesdoc'
        AND      CNAME = 'totiva' )) THEN 
        
		alter table sk_tesdoc add totiva numeric(18,4) DEFAULT NULL ;
end if;

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'sk_rigdoc'
        AND      CNAME = 'id_utente' )) THEN 
        
		alter table sk_rigdoc add id_utente integer DEFAULT NULL ;
end if;

IF (EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'sk_tesdoc'
        AND      CNAME = 'datadoc' )) THEN 
		alter table sk_tesdoc
		modify datadoc char(10) default null;
END IF;

IF (EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'sk_rigdoc'
        AND      CNAME = 'datadoc' )) THEN 
		alter table sk_rigdoc
		modify datadoc char(10) default null;
END IF;

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'sk_rigdoc'
        AND      CNAME = 'id_uc' )) THEN 
        
		alter table sk_rigdoc add id_uc integer DEFAULT NULL ;
end if;

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'tv_cfgprof'
        AND      CNAME = 'id_prof_ord' )) THEN 
        
		alter table tv_cfgprof add id_prof_ord integer DEFAULT NULL ;
end if;

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSTABLE
        WHERE  TABLE_NAME = 'sk_nuovicli')) THEN
		
CREATE TABLE "dba"."sk_nuovicli" ("id_sk_nuovicli" integer NOT NULL DEFAULT autoincrement, "descrizione" char(50) NOT NULL DEFAULT NULL, "indirizzo" char(50) DEFAULT NULL, "localita" char(50) DEFAULT NULL, "piva" char(20) DEFAULT NULL, "cf" char(30) DEFAULT NULL, "pagam" char(30) DEFAULT NULL, "codlis" char(8) DEFAULT NULL, "codice" char(8) DEFAULT NULL, "id_utente" integer NOT NULL DEFAULT NULL , PRIMARY KEY ("id_sk_nuovicli")) ;
CREATE UNIQUE INDEX "ix_sk_nuovicli_1" ON "dba"."sk_nuovicli" ("descrizione" , "id_sk_nuovicli" , "id_utente" ) ;

end if;

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'sk_tesdoc'
        AND      CNAME = 'ragcli' )) THEN 
		alter table sk_tesdoc add ragcli char(50) default null;
END IF;

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSTABLE
        WHERE  TABLE_NAME = 'sk_pagam')) THEN
		
CREATE TABLE "dba"."sk_pagam" ("id_sk_pagam" integer NOT NULL DEFAULT autoincrement, "codice" char(8) NOT NULL DEFAULT NULL, "descrizione" char(40) DEFAULT NULL, "id_utente" integer NOT NULL DEFAULT NULL , PRIMARY KEY ("id_sk_pagam")) ;
CREATE UNIQUE INDEX "ix_sk_pagam_1" ON "dba"."sk_pagam" ("codice" , "id_utente" ) ;
		
end if;		

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'sk_clienti'
        AND      CNAME = 'codpagam' )) THEN 
        
		alter table sk_clienti add codpagam char(8) DEFAULT NULL ;
end if; 

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'tv_giri'
        AND      CNAME = 'codsog' )) THEN 
        
		alter table tv_giri add codsog char(8) DEFAULT NULL ;
end if; 

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'tv_giri'
        AND      CNAME = 'coddest' )) THEN 
        
		alter table tv_giri add coddest char(8) DEFAULT NULL ;
end if; 

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'tv_giri'
        AND      CNAME = 'id_utente' )) THEN 
        
		alter table tv_giri add id_utente integer DEFAULT NULL ;
end if; 

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'sk_nuovicli'
        AND      CNAME = 'codlis' )) THEN 
		alter table sk_nuovicli add codlis char(8) default null;
END IF;

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'sk_nuovicli'
        AND      CNAME = 'codice' )) THEN 
		alter table sk_nuovicli add codice char(8) default null;
END IF;

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'sk_nuovicli'
        AND      CNAME = 'id_utente' )) THEN 
		alter table sk_nuovicli add id_utente integer default null;
END IF;

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSTABLE
        WHERE  TABLE_NAME = 'sk_nuovedest')) THEN
		
CREATE TABLE "dba"."sk_nuovedest" ("id_sk_nuovedest" integer NOT NULL DEFAULT autoincrement, "codice" char(8) DEFAULT NULL, "codcli" char(8) DEFAULT NULL, "descrizione" char(50) DEFAULT NULL, "localita" char(50) DEFAULT NULL, "id_utente" integer NOT NULL DEFAULT NULL, "descli" char(50) NOT NULL DEFAULT NULL , PRIMARY KEY ("id_sk_nuovedest")) ;
CREATE UNIQUE INDEX "ix_sk_nuovedest_1" ON "dba"."sk_nuovedest" ("descli" , "id_sk_nuovedest" , "id_utente" ) ;

end if;

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'sk_tesdoc'
        AND      CNAME = 'codlis' )) THEN 
		
		ALTER TABLE "dba"."sk_tesdoc" add "codlis" char(8) DEFAULT NULL;
end if;
		
IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'sk_tesdoc'
        AND      CNAME = 'codpagam' )) THEN 	
		
		ALTER TABLE "dba"."sk_tesdoc" add "codpagam" char(8) DEFAULT NULL;
end if;		

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'sk_clienti'
        AND      CNAME = 'iban' )) THEN 
		
		ALTER TABLE "dba"."sk_clienti" add "iban" char(20) DEFAULT NULL;
end if;
		
IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'sk_clienti'
        AND      CNAME = 'tel' )) THEN 
		
		ALTER TABLE "dba"."sk_clienti" add "tel" char(80) DEFAULT NULL;
end if;

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'sk_clienti'
        AND      CNAME = 'mail' )) THEN 	
		
		ALTER TABLE "dba"."sk_clienti" add "mail" char(80) DEFAULT NULL;
end if;

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'sk_clienti'
        AND      CNAME = 'note_cli' )) THEN 
			
		ALTER TABLE "dba"."sk_clienti" add "note_cli" char(256) DEFAULT NULL;
end if;
		
IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'sk_rigdoc'
        AND      CNAME = 'codiva' )) THEN 
		
		ALTER TABLE "dba"."sk_rigdoc" add "codiva" char(8) DEFAULT NULL;
end if;
		
IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSTABLE
        WHERE  TABLE_NAME = 'sk_scadenza')) THEN
		
		CREATE TABLE "dba"."sk_scadenza" ("id_sk_scadenze" integer NOT NULL DEFAULT autoincrement, "data_scad" date NOT NULL DEFAULT NULL, "segno" integer NOT NULL DEFAULT NULL, "des_scadenza" char(80) NOT NULL DEFAULT NULL, "importo" numeric(18,2) DEFAULT NULL, "codcli" char(8) DEFAULT NULL , PRIMARY KEY ("id_sk_scadenze")) ;
end if;
		
IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSTABLE
        WHERE  TABLE_NAME = 'sk_tv_giri')) THEN
		
		CREATE TABLE "dba"."sk_tv_giri" ("id_sk_tv_giri" integer NOT NULL DEFAULT autoincrement, "seq" integer NOT NULL DEFAULT NULL, "codcli" char(8) DEFAULT NULL, "coddest" char(8) DEFAULT NULL , PRIMARY KEY ("id_sk_tv_giri")) ;
end if;		
		
IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'sk_tv_giri'
        AND      CNAME = 'id_tv_term' )) THEN 
		
		ALTER TABLE "dba"."sk_tv_giri" add "id_tv_term" integer DEFAULT NULL;
end if;

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'sk_tv_giri'
        AND      CNAME = 'giorno' )) THEN 
		
		ALTER TABLE "dba"."sk_tv_giri" add "giorno" integer DEFAULT NULL;
end if;

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSTABLE
        WHERE  TABLE_NAME = 'sk_tesord')) THEN
		
CREATE TABLE "dba"."sk_tesord" ("id_sk_tesord" integer NOT NULL DEFAULT autoincrement, "tipo" char(1) NOT NULL DEFAULT NULL, "numdoc" integer NOT NULL DEFAULT NULL, "datadoc" char(10) NOT NULL DEFAULT NULL, "codcli" char(8) DEFAULT NULL, "dest" char(8) DEFAULT NULL, "totdoc" numeric(18,4) DEFAULT NULL, "id_utente" integer NOT NULL DEFAULT NULL, "totmer" numeric(18,4) DEFAULT NULL, "totiva" numeric(18,4) DEFAULT NULL, "ragcli" char(50) DEFAULT NULL, "codlis" char(8) DEFAULT NULL, "codpagam" char(8) DEFAULT NULL, "id_sk_doc" integer DEFAULT NULL , PRIMARY KEY ("id_sk_tesord")) ;
CREATE UNIQUE INDEX "ix_sk_tesdoc_1" ON "dba"."sk_tesord" ("tipo" , "datadoc" , "numdoc" , "id_utente" ) ;

end if;

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSTABLE
        WHERE  TABLE_NAME = 'sk_rigord')) THEN
		
		CREATE TABLE "dba"."sk_rigord" ("id_sk_rigord" integer NOT NULL DEFAULT autoincrement, "tipo" char(1) DEFAULT NULL, "numdoc" integer DEFAULT NULL, "datadoc" char(10) DEFAULT NULL, "codart" char(32) DEFAULT NULL, "barcode" char(24) DEFAULT NULL, "qta" numeric(18,4) DEFAULT NULL, "prezzo" numeric(18,4) DEFAULT NULL, "sconto" numeric(18,4) DEFAULT NULL, "impnetto" numeric(18,4) DEFAULT NULL, "impiva" numeric(18,4) DEFAULT NULL, "id_utente" integer DEFAULT NULL, "id_uc" integer DEFAULT NULL, "note_riga" char(256) DEFAULT NULL, "codiva" char(8) DEFAULT NULL, PRIMARY KEY ("id_sk_rigord")) ;
		CREATE INDEX "ix_sk_rigdoc_1" ON "dba"."sk_rigord" ("tipo" , "datadoc" , "numdoc" , "codart" ) ;
end if;

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'sk_tesord'
        AND      CNAME = 'id_sk_doc' )) THEN 
		
		ALTER TABLE "dba"."sk_tesord" add "id_sk_doc" integer DEFAULT NULL;
end if;


IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'sk_articoli'
        AND      CNAME = 'corsia' )) THEN 
		
		ALTER TABLE sk_articoli add "corsia" char(8) DEFAULT NULL;
end if;

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'sk_articoli'
        AND      CNAME = 'scaffale' )) THEN 	
		
		ALTER TABLE sk_articoli add "scaffale" char(10) DEFAULT NULL;
end if;

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'sk_articoli'
        AND      CNAME = 'ripiano' )) THEN 	
		
	ALTER TABLE sk_articoli add "ripiano" char(10) DEFAULT NULL;
end if;

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'sk_articoli'
        AND      CNAME = 'posizione' )) THEN 
		
		ALTER TABLE sk_articoli add "posizione" char(10) DEFAULT NULL;
end if;		

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'sk_contatori'
        AND      CNAME = 'fatture' )) THEN 	
		
		ALTER TABLE "dba"."sk_contatori" add "fatture" integer DEFAULT NULL;
end if;	

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'sk_rigdoc'
        AND      CNAME = 'id_sk_rigder' )) THEN 	
		
		ALTER TABLE "dba"."sk_rigdoc" add "id_sk_rigder" integer DEFAULT NULL;
end if;	


IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'tv_cfgprof'
        AND      CNAME = 'id_prof_resi' )) THEN 	
		
		ALTER TABLE "dba"."tv_cfgprof" add "id_prof_resi" integer DEFAULT NULL;
end if;	

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'tv_term'
        AND      CNAME = 'wce_odbc' )) THEN 	
		
		ALTER TABLE "dba"."tv_term" add "wce_odbc" char(30) DEFAULT NULL;
end if;	
////////////////////////////////////



IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'par_sistema'
        AND      CNAME = 'id_prof_reg_ic' )) THEN 
        
	alter table par_sistema add id_prof_reg_ic integer DEFAULT null;
	alter table par_sistema add id_mod_reg_ic integer DEFAULT null;

	if EXISTS(select 1 from par_sistema where gest_var1='S') then
	   CREATE INDEX "ix_riga_documento_var1" ON "dba"."riga_documento" ("id_art_var1" ) ;
	end if;
end if;


IF NOT EXISTS(
        SELECT 1 
        FROM   SYS.SYSPROCEDURE
        WHERE  PROC_NAME = 'fn_tipo_anag') THEN

	CREATE FUNCTION "DBA"."fn_tipo_anag"(in @rd_anag integer)
	returns char(40)
	begin
	  declare @ls_tipo char(2);
	  declare @ls_ret char(40);
	  
	  declare cur_sog dynamic scroll cursor for 
	    Select tipo from sog_commerciale where id_anagrafica=@rd_anag;
	
	   open cur_sog;
	   fetch next cur_sog into @ls_tipo;
	   while sqlcode=0 loop
	    	if @ls_tipo='C' then 
        	    set @ls_tipo='CL'
	        end if;
	    	if @ls_tipo='A' then 
	            set @ls_tipo='AG'
	        end if;
	    	if @ls_tipo='V' then 
	            set @ls_tipo='VT'
	        end if;
	    	if @ls_tipo='F' then 
	            set @ls_tipo='FO'
	        end if;
			if @ls_ret is null or @ls_ret='' then 
	    		set @ls_ret=@ls_tipo
	    	else	    
	    		set @ls_ret=@ls_ret + ' - ' + @ls_tipo
		    end if;
    
	    fetch next cur_sog into @ls_tipo
	  end loop  ;
  
	  return(@ls_ret)
	end;

END IF;

//per CCT
IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'cct_doc_ext'
        AND      CNAME = 'registro' )) THEN 
        
		alter table cct_doc_ext add "registro" char(5) DEFAULT NULL;
end if; 
////////////////


IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'par_sistema'
        AND      CNAME = 'upper_cod_art' )) THEN 
        
	alter table par_sistema add upper_cod_art char(1) DEFAULT 'N';
	update par_sistema set upper_cod_art='N';
end if;

//PAD export lavoro domicilio su file
IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSTABLE
        WHERE  TABLE_NAME = 'pad_expdom')) THEN
		
		CREATE TABLE "dba"."pad_expdom" ("id_pad_expdom" integer NOT NULL DEFAULT autoincrement, "id_fornitore" integer DEFAULT NULL, "coddipnrp" char(21) DEFAULT NULL, "codsoggdipn" char(8) DEFAULT NULL, "numrapp" integer DEFAULT NULL, "vfgenrautmteor" char(1) DEFAULT NULL , PRIMARY KEY ("id_pad_expdom")) ;
		CREATE UNIQUE INDEX "ix_pad_expdom_1" ON "dba"."pad_expdom" ("id_fornitore" ) ;
end if;		
/////////////////////////////////////



//////UNITA CONFEZIONE ACQUISTO SENATORI
IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'unita_confezione'
        AND      CNAME = 'id_um_acquisto' )) THEN 
	
	ALTER TABLE unita_confezione ADD "id_um_acquisto" integer DEFAULT NULL;
	ALTER TABLE unita_confezione ADD "fat_conv_acq" numeric(20,12) DEFAULT NULL;
	UPDATE unita_confezione SET id_um_acquisto=id_unita_misura, fat_conv_acq=1;
end if;		

if (SELECT codice FROM   AZIENDA)<>'CREART' and (SELECT codice FROM   AZIENDA)<>'PRECIOUS' then
	ALTER TRIGGER "t_articolo_ai" after insert order 1
	on "DBA".articolo
	referencing new as new_articolo
	for each row
	begin
	  /* Moneti Elisa  		25/03/1999
	  Oggetto: Creazione dell'Unita' Confezione di base.
	
	  - 	se nell'Articolo e' specificato il 
	  modello di unita' di base (articolo.id_unita_conf_base):
	  Unita' di base dell'Articolo = Modello.

	  -	se l'Articolo  una Variante:
	  Unita' di base = Unita' di base dell'Articolo padre

	  -	altrimenti Unita' di base = standard,  con i valori di default.
	  */
	  declare @ll_id_articolo integer;
	  declare @ll_id_unita_conf_base integer;
	  declare @ll_id_cat_codifica integer;
	  declare @ll_lun_parte_fissa integer;
	  declare @ls_cod_padre char(32);
	  declare @ls_codice char(32);
  /**/
  /**/
  set @ll_id_articolo=new_articolo.id_articolo;
  set @ls_codice=new_articolo.codice;
  set @ll_id_unita_conf_base=new_articolo.id_unita_conf_base;
  set @ll_id_cat_codifica=new_articolo.id_cat_codifica;
  /**/
  /**/
  if(@ll_id_unita_conf_base is not null) then
    insert into "dba".unita_confezione(id_articolo,codice,id_unita_misura,
      descrizione,app_conversione,fat_conversione,tipo_conversione,
      molteplicita,qta_minima,qta_massima,id_unita_mis_peso,
      peso_netto,peso_lordo,id_unita_mis_volume,dim_l,dim_h,dim_p,
      unita_base,unita_prezzo,unita_documenti,unita_produzione,
      num_colli,id_um_acquisto,fat_conv_acq,)
      select @ll_id_articolo,codice,id_unita_misura,descrizione,
        app_conversione,fat_conversione,tipo_conversione,molteplicita,
        qta_minima,qta_massima,id_unita_mis_peso,peso_netto,
        peso_lordo,id_unita_mis_volume,dim_l,dim_h,dim_p,'S',
        unita_prezzo,unita_documenti,unita_produzione,num_colli,id_unita_misura,1
        from unita_conf_base
        where id_unita_conf_base=@ll_id_unita_conf_base
  else
    /* Verifico se l'Articolo e' una Variante */
    /* Recupero la parte fissa di codice, precedente la variante */
    select SUM(p.lunghezza) into @ll_lun_parte_fissa
      from parte_regola as p,cat_codifica as c
      where c.id_cat_codifica=@ll_id_cat_codifica
      and p.id_scomposizione=c.id_scomposizione
      and p.num_sezione<(select MIN(num_sezione)
        from parte_regola
        where id_scomposizione=c.id_scomposizione
        and variante='S');
    if(@ll_lun_parte_fissa>0 and(@ll_lun_parte_fissa is not null)) then
      /* Recupero, se esiste, l''Articolo Padre */
      select MIN(codice) into @ls_cod_padre
        from articolo
        where id_cat_codifica=@ll_id_cat_codifica
        and SUBSTR(codice,1,@ll_lun_parte_fissa)=SUBSTR(@ls_codice,1,@ll_lun_parte_fissa)
    end if
    ;
    if(@ls_cod_padre is not null) then
      insert into "dba".unita_confezione(id_articolo,codice,
        id_unita_misura,descrizione,app_conversione,
        fat_conversione,tipo_conversione,molteplicita,
        qta_minima,qta_massima,id_unita_mis_peso,
        peso_netto,peso_lordo,id_unita_mis_volume,
        dim_l,dim_h,dim_p,unita_base,unita_prezzo,
        unita_documenti,unita_produzione,num_colli)
        select @ll_id_articolo,u.codice,u.id_unita_misura,
          u.descrizione,u.app_conversione,u.fat_conversione,
          u.tipo_conversione,u.molteplicita,u.qta_minima,
          u.qta_massima,u.id_unita_mis_peso,u.peso_netto,
          u.peso_lordo,u.id_unita_mis_volume,u.dim_l,u.dim_h,
          u.dim_p,'S',u.unita_prezzo,u.unita_documenti,
          u.unita_produzione,u.num_colli
          from unita_confezione as u,articolo as a
          where a.codice=@ls_cod_padre
          and u.id_articolo=a.id_articolo
          and u.unita_base='S'
	    else
	      insert into "dba".unita_confezione(id_articolo,codice,descrizione,
	        app_conversione,fat_conversione,tipo_conversione,
	        molteplicita,unita_base,unita_documenti) values(
	        @ll_id_articolo,'UNITA`','Unita` Standard','F',1,'M',
	        1,'S','S')
	    end if
	  end if
	end;
end if;

//SENATORI
IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'arrotondamento'
        AND      CNAME = 'dec_significativi' )) THEN 
	alter table  arrotondamento add dec_significativi integer;
end if;

//Gestione Commesse (movimenti costi esterni all'ultimo costo o da listino)
IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'com_par_prof'
        AND      CNAME = 'ultimo_costo' )) THEN 
	alter table  com_par_prof add ultimo_costo char(1) DEFAULT NULL;
end if;

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'com_par_prof'
        AND      CNAME = 'id_variazione' )) THEN 
	alter table  com_par_prof add id_variazione integer DEFAULT NULL;
end if;



IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'utenti'
        AND      CNAME = 'no_login' )) THEN 
	alter table  utenti add no_login char(1) DEFAULT NULL;
	update utenti set no_login='N';
end if;


IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'arky_note'
        AND      CNAME = 'color' )) THEN 
	alter table  arky_note add color char(20) DEFAULT NULL;
	update arky_note set color='16777215';
end if;

//Gestione economie x Sansone
IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSTABLE
        WHERE  TABLE_NAME = 'com_economia')) THEN
		
		CREATE TABLE "dba"."com_economia" ("id_com_economia" integer NOT NULL DEFAULT autoincrement, "id_commessa" integer DEFAULT NULL, "numero" integer NOT NULL DEFAULT NULL, "datareg" date DEFAULT NULL , PRIMARY KEY ("id_com_economia")) ;
		CREATE UNIQUE INDEX "ix_com_economia_1" ON "dba"."com_economia" ("numero" , "datareg" , "id_com_economia" ) ;
end if;

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'com_economie'
        AND      CNAME = 'id_com_economia' )) THEN 
		alter table  com_economie add id_com_economia integer DEFAULT NULL;
		alter table  com_economie add FOREIGN KEY "FK_com_economie_2" ("id_com_economia" ) REFERENCES "dba"."com_economia" ON DELETE CASCADE ; 
end if;
///////////////////////////////////////////////



//GESTIONE SCHEDA TRASPORTO

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSTABLE
        WHERE  TABLE_NAME = 'doc_scheda_trasp')) THEN

	alter table prof_documento add scheda_trasp char(1) default 'N';
	update prof_documento set scheda_trasp='N';
	alter table sog_commerciale add scheda_trasp char(1) default 'N';
	update sog_commerciale set scheda_trasp='N';
	alter table sog_commerciale add iscr_albo_trasp char(80);

	CREATE TABLE "dba"."doc_scheda_trasp" ("id_doc_scheda_trasp" integer NOT NULL DEFAULT autoincrement, 
		"id_documento" integer NOT NULL DEFAULT NULL, "id_vettore" integer DEFAULT NULL, 
		"rag_vettore" char(256) DEFAULT NULL, "ind_vettore" char(256) DEFAULT NULL, "pi_vettore" char(256) DEFAULT NULL, 
		"tel_vettore" char(256) DEFAULT NULL, "iscr_vettore" char(256) DEFAULT NULL, "tipo_committente" char(1) DEFAULT NULL, 
		"id_committente" integer DEFAULT NULL, "rag_committente" char(256) DEFAULT NULL, "ind_committente" char(256) DEFAULT NULL, 
		"pi_committente" char(256) DEFAULT NULL, "tel_committente" char(256) DEFAULT NULL, "tipo_caricatore" char(1) DEFAULT NULL, 
		"id_caricatore" integer DEFAULT NULL, "rag_caricatore" char(256) DEFAULT NULL, "ind_caricatore" char(256) DEFAULT NULL, 
		"pi_caricatore" char(256) DEFAULT NULL, "tel_caricatore" char(256) DEFAULT NULL, 
		"tipo_proprietario" char(1) DEFAULT NULL, "id_proprietario" integer DEFAULT NULL, 
		"rag_proprietario" char(256) DEFAULT NULL, "ind_proprietario" char(256) DEFAULT NULL, "pi_proprietario" char(256) DEFAULT NULL, 
		"tel_proprietario" char(256) DEFAULT NULL, "indicazioni" char(256) DEFAULT NULL, 
		"tipologia" char(256) DEFAULT NULL, "quantita" char(256) DEFAULT NULL, "peso" char(256) DEFAULT NULL, "luogo_carico" char(256) DEFAULT NULL, 
		"luogo_scarico" char(256) DEFAULT NULL, "osservazioni" char(256) DEFAULT NULL, "istruzioni" char(256) DEFAULT NULL , 
		PRIMARY KEY ("id_doc_scheda_trasp") , FOREIGN KEY "fk_doc_scheda_trasp_1" ("id_documento" ) REFERENCES "dba"."documento" ON DELETE CASCADE ) ;

end if;


IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSTABLE
        WHERE  TABLE_NAME = 'catalogo')) THEN

	CREATE TABLE "dba"."catalogo" ("id_catalogo" integer NOT NULL DEFAULT autoincrement, 
		"codice" char(8) NOT NULL DEFAULT NULL, "descrizione" char(80) NOT NULL DEFAULT NULL, 
		"id_art_da" integer DEFAULT NULL, "id_art_ad" integer DEFAULT NULL, "da_data" date DEFAULT NULL, 
		"ad_data" date DEFAULT NULL, "id_fornitore" integer DEFAULT NULL, "ordinamento" char(1) DEFAULT NULL, 
		"dimensioni" char(1) DEFAULT NULL, "formato" char(1) DEFAULT NULL, "esc_inutilizzati" char(1) DEFAULT NULL, 
		"esc_immagini" char(1) DEFAULT NULL, "gruppo" char(1) DEFAULT NULL , PRIMARY KEY ("id_catalogo")) ;
	CREATE UNIQUE INDEX "xk_catalogo" ON "dba"."catalogo" ("codice" ) ;

	CREATE TABLE "dba"."catalogo_ccom" ("id_catalogo_ccom" integer NOT NULL DEFAULT autoincrement, "id_catalogo" integer NOT NULL DEFAULT NULL, "id_cat_commerciale" integer NOT NULL DEFAULT NULL , PRIMARY KEY ("id_catalogo_ccom") , FOREIGN KEY "fk_catalogo_ccom" ("id_catalogo" ) REFERENCES "dba"."catalogo" ON DELETE RESTRICT ) ;
	CREATE TABLE "dba"."catalogo_cmer" ("id_catalogo_cmer" integer NOT NULL DEFAULT autoincrement, "id_catalogo" integer NOT NULL DEFAULT NULL, "id_cat_merceologica" integer NOT NULL DEFAULT NULL , PRIMARY KEY ("id_catalogo_cmer") , FOREIGN KEY "fk_catalogo_cmer" ("id_catalogo" ) REFERENCES "dba"."catalogo" ON DELETE RESTRICT ) ;
	CREATE TABLE "dba"."catalogo_cfis" ("id_catalogo_cfis" integer NOT NULL DEFAULT autoincrement, "id_catalogo" integer NOT NULL DEFAULT NULL, "id_cat_fiscale" integer NOT NULL DEFAULT NULL , PRIMARY KEY ("id_catalogo_cfis") , FOREIGN KEY "fk_catalogo_cfis" ("id_catalogo" ) REFERENCES "dba"."catalogo" ON DELETE RESTRICT ) ;
	CREATE TABLE "dba"."catalogo_cgrp" ("id_catalogo_cgrp" integer NOT NULL DEFAULT autoincrement, "id_catalogo" integer NOT NULL DEFAULT NULL, "id_gruppo_articoli" integer NOT NULL DEFAULT NULL , PRIMARY KEY ("id_catalogo_cgrp") , FOREIGN KEY "fk_catalogo_cgrp" ("id_catalogo" ) REFERENCES "dba"."catalogo" ON DELETE RESTRICT ) ;


end if;


///
IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'sk_articoli'
        AND      CNAME = 'area' )) THEN 
	ALTER TABLE sk_articoli add  "area" char(10) DEFAULT NULL ;
end if;

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'sk_rigord'
		AND      CNAME = 'corsia' )) THEN
		
		ALTER TABLE "dba"."sk_rigord" add "corsia" char(8) DEFAULT NULL ;
end if;

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'sk_rigord'
		AND      CNAME = 'scaffale' )) THEN
		
		ALTER TABLE "dba"."sk_rigord" add "scaffale" char(10) DEFAULT NULL ;
end if;

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'sk_rigord'
		AND      CNAME = 'ripiano' )) THEN
		
		ALTER TABLE "dba"."sk_rigord" add "ripiano" char(10) DEFAULT NULL ;
end if;

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'sk_rigord'
		AND      CNAME = 'posizione' )) THEN
		
		ALTER TABLE "dba"."sk_rigord" add "posizione" char(10) DEFAULT NULL ;
end if;

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'sk_rigord'
		AND      CNAME = 'area' )) THEN
		
		ALTER TABLE "dba"."sk_rigord" add "area" char(10) DEFAULT NULL ;
end if;
////**********************



//AVVISO SE ORDINATO A FORNITORE
IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'par_sistema'
        AND      CNAME = 'doc_avviso_in_ordacq' )) THEN 

	alter table par_sistema add doc_avviso_in_ordacq char(1);
	update par_sistema set doc_avviso_in_ordacq=doc_avviso_in_ordine;

end if;

//VARIANTI COMPONENTE
IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'riga_componente'
        AND      CNAME = 'id_art_var1' )) THEN 

	ALTER TABLE "dba"."riga_componente" add "pk_codice" char(20) DEFAULT NULL;
	update "dba"."riga_componente" set "pk_codice"='N@N@N';
	ALTER TABLE "dba"."riga_componente" add "id_art_var1" integer DEFAULT NULL;
	ALTER TABLE "dba"."riga_componente" add "id_art_var2" integer DEFAULT NULL;
	ALTER TABLE "dba"."riga_componente" add "id_art_var3" integer DEFAULT NULL;
	ALTER TABLE "dba"."riga_componente" modify "pk_codice" char(20) NOT NULL DEFAULT NULL;
	ALTER TABLE "dba"."riga_componente" drop PRIMARY KEY;
	ALTER TABLE "dba"."riga_componente" add PRIMARY KEY ("id_componente", "id_articolo", "pk_codice");


	CREATE TRIGGER "t_riga_componente_bi" BEFORE INSERT
		ORDER 1 ON "DBA"."riga_componente"
		REFERENCING NEW AS new_pz
		FOR EACH ROW /* WHEN( search_condition ) */
		BEGIN	
		    declare @ls_var1 long varchar;
		    declare @ls_var2 long varchar;
		    declare @ls_var3 long varchar;
		    if new_pz.id_art_var1 is null then 
		       set @ls_var1='N'
		    else
		        set @ls_var1=string(new_pz.id_art_var1)
		    end if;
		    if new_pz.id_art_var2 is null then 
	        	set @ls_var2='N'
		    else
	        	set @ls_var2=string(new_pz.id_art_var2)
			    end if;
		    	if new_pz.id_art_var3 is null then 
			        set @ls_var3='N'
	    		else
			        set @ls_var3=string(new_pz.id_art_var3)
		    end if;
		    SET new_pz.pk_codice=@ls_var1+'@'+@ls_var2+'@'+@ls_var3;
	END;

	CREATE TRIGGER "t_riga_componente_bu" BEFORE UPDATE
		ORDER 1 ON "DBA"."riga_componente"
		REFERENCING NEW AS new_pz
		FOR EACH ROW /* WHEN( search_condition ) */
		BEGIN
		    declare @ls_var1 long varchar;
		    declare @ls_var2 long varchar;
		    declare @ls_var3 long varchar;
		    if new_pz.id_art_var1 is null then 
		       set @ls_var1='N'
		    else
		        set @ls_var1=string(new_pz.id_art_var1)
		    end if;
		    if new_pz.id_art_var2 is null then 
		        set @ls_var2='N'
		    else	
		        set @ls_var2=string(new_pz.id_art_var2)
		    end if;
		    if new_pz.id_art_var3 is null then 
	        	set @ls_var3='N'
		    else
		        set @ls_var3=string(new_pz.id_art_var3)
		    end if;
		SET new_pz.pk_codice=@ls_var1+'@'+@ls_var2+'@'+@ls_var3;	
	END;

end if;


///Parametro connessione Terminali WinCE o WM5
IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'pers_par_sistema'
        AND      CNAME = 'conn_mobile' )) THEN 
	alter table  pers_par_sistema add conn_mobile char(120) DEFAULT NULL;
end if;

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSTABLE
        WHERE  TABLE_NAME = 'sk_storico')) THEN

	CREATE TABLE "dba"."sk_storico" ("id_sk_storico" integer NOT NULL DEFAULT autoincrement, 
	"cod_art" char(32) NOT NULL DEFAULT NULL, "barcode" char(24) DEFAULT NULL, "qta" bigint DEFAULT NULL, 
	"ult_acquisto" date DEFAULT NULL, "cod_cli" char(8) NOT NULL , PRIMARY KEY ("id_sk_storico")) ;
	CREATE UNIQUE INDEX "xk_storico_1" ON "dba"."sk_storico" ("cod_art", "cod_cli") ;

end if;

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSTABLE
        WHERE  TABLE_NAME = 'assegni')) THEN

	CREATE TABLE "dba"."assegni" ("id_assegni" integer NOT NULL DEFAULT autoincrement, "id_conto" integer NOT NULL DEFAULT NULL, 
				      "tipo_assegno" char(1) NOT NULL DEFAULT NULL, "importo" decimal(18,2) NOT NULL DEFAULT NULL, 
                                      "data_scadenza" date DEFAULT NULL, "data_compilazione" date DEFAULT NULL, "esito_pagamento" char(1) NOT NULL DEFAULT NULL, 
				      "num_assegno" char(80) DEFAULT NULL, "banca" char(256) DEFAULT NULL, "utente" char(80) DEFAULT NULL, "note" char(256) DEFAULT NULL, 
				      "id_cpt" integer DEFAULT NULL, "id_reg_pd" integer DEFAULT NULL , PRIMARY KEY ("id_assegni") , FOREIGN KEY "fk_assegni_reg_pd" ("id_reg_pd" ) REFERENCES "dba"."reg_pd" ON DELETE CASCADE ) ;

	CREATE TABLE "dba"."assegni_riga" ("id_assegni_riga" integer NOT NULL DEFAULT autoincrement, "id_assegni" integer NOT NULL DEFAULT NULL, 
		"id_documento" integer DEFAULT NULL, "id_par_aperta" integer DEFAULT NULL, "id_scadenza" integer DEFAULT NULL, 
		"des_documento" char(80) DEFAULT NULL , PRIMARY KEY ("id_assegni_riga") , FOREIGN KEY "fk_assegni_riga" ("id_assegni" ) REFERENCES "dba"."assegni" ON DELETE CASCADE ) ;

end if;


IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'assegni'
        AND      CNAME = 'id_mov_contabile' )) THEN 
	alter table  assegni add id_mov_contabile integer DEFAULT NULL;
end if;


IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSTABLE
        WHERE  TABLE_NAME = 'par_assegni')) THEN

	CREATE TABLE "dba"."par_assegni" ("id_par_assegni" integer NOT NULL DEFAULT autoincrement, 
	"pref_cpt_risc" char(2) DEFAULT NULL, "id_cpt_risc" integer DEFAULT NULL, "pref_cpt_pag" char(2) DEFAULT NULL, 
	"id_cpt_pag" integer DEFAULT NULL, "id_prof_risc" integer DEFAULT NULL, "id_prof_risc_ins" integer DEFAULT NULL, 
	"id_prof_pag" integer DEFAULT NULL, "pref_mm_risc" char(2) DEFAULT NULL, "pref_mm_pag" char(2) DEFAULT NULL, 
	"tipo_contab" char(1) DEFAULT NULL, "data_contab" char(1) DEFAULT NULL , PRIMARY KEY ("id_par_assegni")) ;

	insert into par_assegni (id_par_assegni) values (1);

	update par_assegni a, par_sistema p set
	a.id_cpt_risc=p.id_conto_cpt_risc,
	a.id_prof_risc_ins=p.id_prof_reg_risc_ins,
	a.id_prof_risc=p.id_prof_reg_risc;

end if;


IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSTABLE
        WHERE  TABLE_NAME = 'fat_param_ia')) THEN

	CREATE TABLE "dba"."fat_param_ia" ("id_fat_param_ia" integer NOT NULL DEFAULT autoincrement, "id_documento" integer NOT NULL DEFAULT NULL, "id_prof_documento" integer NOT NULL DEFAULT NULL, "id_registro" integer NOT NULL DEFAULT NULL, "tipo_registro" char(2) NOT NULL DEFAULT NULL, "num_progressivo" integer NOT NULL DEFAULT NULL, "data_registrazione" date NOT NULL DEFAULT NULL, "segno_iva" integer NOT NULL DEFAULT NULL, "id_sog_comerciale" integer NOT NULL DEFAULT NULL, "id_destinazione" integer DEFAULT NULL, "id_riga_documento" integer NOT NULL DEFAULT NULL, "id_articolo" integer DEFAULT NULL, "des_articolo" char(256) DEFAULT NULL, "tipo_um" char(1) DEFAULT NULL, "quantita" numeric(20,6) DEFAULT NULL, "tot_scontato" numeric(20,6) DEFAULT NULL, "id_reg_pd" integer NOT NULL DEFAULT NULL, "id_cpt" integer DEFAULT NULL, "id_gruppo_agenti" integer DEFAULT NULL, "id_gruppo_agenti_2" integer DEFAULT NULL, "id_var1" integer DEFAULT NULL, "origine" char(40) DEFAULT NULL, "dim_l" numeric(18,4) DEFAULT NULL , PRIMARY KEY 	("id_fat_param_ia") , FOREIGN KEY "fk_fat_parametrico_id_art" ("id_articolo" ) REFERENCES "dba"."articolo" ON DELETE RESTRICT , FOREIGN KEY "fk_fat_parametrico_id_sog" ("id_sog_comerciale" ) REFERENCES "dba"."sog_commerciale" ON DELETE RESTRICT ) ;
	CREATE UNIQUE INDEX "xk_fat_parametrico_id_riga_doc" ON "dba"."fat_param_ia" ("id_riga_documento" ) ;
	CREATE INDEX "xk_fat_parametrico_data" ON "dba"."fat_param_ia" ("data_registrazione" ) ;
	CREATE INDEX "xk_fat_parametrico_id_art" ON "dba"."fat_param_ia" ("id_articolo" ) ;
	CREATE INDEX "xk_fat_parametrico_id_doc" ON "dba"."fat_param_ia" ("id_documento" ) ;
	CREATE INDEX "xk_fat_parametrico_id_sog" ON "dba"."fat_param_ia" ("id_sog_comerciale" ) ;

end if;

//CCT
IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'nazione'
        AND      CNAME = 'id_tab_iva' )) THEN 
	alter table  nazione add id_tab_iva integer DEFAULT NULL;
end if;
///////////////////////////////

//Copia locazioni di origine su destinazione durante la derivazione interattiva (Belardi)
IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'prof_documento'
        AND      CNAME = 'copia_locaz_deriv' )) THEN 
		
		ALTER TABLE prof_documento add "copia_locaz_deriv" char(1) DEFAULT 'N';
end if;	
/////////////////////////////////////////////////////////////////////////////////////////

//COMPENSI

call fn_ins_voce_menu('Registrazioni Contabili', 'w_compensi_schede_rpt', 'Schede Compensi', 27);
call fn_ins_voce_menu('Registrazioni Contabili', 'w_compensi_registro_rpt', 'Registro Compensi', 28);
call fn_ins_voce_menu('Registrazioni Contabili', 'w_compensi_da_saldare_rpt', 'Compensi da Saldare', 29);


//associa scad
call fn_ins_voce_menu('Gestione Partite', 'w_utility_scadenze_cx', 'Compensazione automatica Scadenze', 61);


///GESTIONE ASSEGNI
IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'mov_scadenza'
        AND      CNAME = 'id_cpt_assegni' )) THEN 
		
	ALTER TABLE "dba"."mov_scadenza" ADD "id_cpt_assegni" integer NULL DEFAULT NULL;
	ALTER TABLE "dba"."par_sistema"  ADD "pref_conto_cpt_risc" char(2);

end if;	

//MADERO STAMPA LOTTI DEPOSITI
IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSTABLE
        WHERE  TABLE_NAME = 'lottidep')) THEN
		CREATE TABLE "dba"."lottidep" ("id_lottidep" integer NOT NULL DEFAULT autoincrement, "id_articolo" integer DEFAULT NULL, "id_lotto" integer DEFAULT NULL, "qta" decimal(18,4) DEFAULT NULL, "id_magazzino" integer DEFAULT NULL , PRIMARY KEY ("id_lottidep")) ;
		CREATE INDEX "ix_lottidep_1" ON "dba"."lottidep" ("id_magazzino" , "id_articolo" , "id_lotto" ) ;
end if;		
/////////////////////////////////



////BELARDI COMMESSE DA CONTABILITA'
IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'com_bilancio'
        AND      CNAME = 'id_mov_contabile' )) THEN 

	ALTER TABLE conto ADD "crea_cdc" char(1) DEFAULT NULL;
	ALTER TABLE "dba"."com_bilancio" ADD "id_mov_contabile" integer DEFAULT NULL;
end if;		

////BELARDI GESTIONE COMMESSA PADRE
IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'commessa'
        AND      CNAME = 'id_commessa_padre' )) THEN 

	ALTER TABLE "dba"."commessa" ADD "id_commessa_padre" integer DEFAULT NULL;
end if;	

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'com_bilancio'
        AND      CNAME = 'sconto' )) THEN 

	ALTER TABLE "dba"."com_bilancio" ADD "sconto" char(40) DEFAULT NULL;
end if;		

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'com_bilancio'
        AND      CNAME = 'prezzo' )) THEN 

	ALTER TABLE "dba"."com_bilancio" ADD "prezzo" numeric(18,4) DEFAULT NULL;
end if;	

////SENATORI VALORE VARIANTI
IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSTABLE
        WHERE  TABLE_NAME = 'var1_valore')) THEN

	CREATE TABLE "dba"."var1_valore" ("id_var1_valore" integer NOT NULL DEFAULT autoincrement, "id_art_var1" integer NOT NULL DEFAULT NULL, "ordine" integer NOT NULL DEFAULT NULL , PRIMARY KEY ("id_var1_valore")) ;
	CREATE UNIQUE INDEX "xk_val_var" ON "dba"."var1_valore" ("id_art_var1" ) ;

end if;		

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'par_assegni'
        AND      CNAME = 'ret_bolle' )) THEN 

	ALTER TABLE par_assegni add "ret_bolle" char(1) DEFAULT NULL;
	ALTER TABLE par_assegni add "raggruppa_assegno" char(1) DEFAULT NULL;
	UPDATE par_assegni set ret_bolle='S';
	UPDATE par_assegni set raggruppa_assegno='N';

	if (SELECT codice FROM   AZIENDA)<>'ALTERINI'  then
	   UPDATE par_assegni set ret_bolle='N';	   
	end if;
	if (SELECT codice FROM   AZIENDA)='PARIGI'  then
	   UPDATE par_assegni set raggruppa_assegno='S';	   
	end if;

end if;		

IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'mov_scadenza'
        AND      CNAME = 'id_assegno' )) THEN 

	ALTER TABLE mov_scadenza ADD id_assegno integer DEFAULT NULL;
end if;		


ALTER TRIGGER "t_Mov_Scad_Agg_Assegni_bd" before delete order 1
	on "DBA".Mov_Scadenza
	referencing old as old_Mov
	for each row
	begin
	  /* [RICCARDO -- ALTERINI]
	  Ricreo il movimento di assegno che verr cancellato dal cascade del mov_partita . */

	  if ((old_Mov.id_scad_riscossione>0 and old_Mov.id_scad_riscossione is not null) or  (old_Mov.id_ins_riscossione>0 and old_Mov.id_ins_riscossione is not null)) and old_mov.id_scadenza>0 then
	     insert into mov_scadenza ("id_scadenza", "data", "importo", "imp_valuta", "note", "id_azienda", 
	                               "id_doc_riscossione", "id_scad_riscossione", "id_ins_riscossione", "id_cpt_assegni", "id_assegno") 
	                       values (0, old_Mov.data, old_Mov.importo, old_Mov.imp_valuta, old_Mov.note, old_Mov.id_azienda, 
	                               old_Mov.id_doc_riscossione, old_Mov.id_scad_riscossione, old_mov.id_ins_riscossione, old_mov.id_cpt_assegni, old_mov.id_assegno) 
      else
          if old_mov.id_scadenza=0 and old_mov.stato_ass='B' then
             raiserror 99999 'Non e'' possibile modificare un movimento assegni con esito bloccato'
          end if
      end if
end;


IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'assegni'
        AND      CNAME = 'id_mov_contabile' )) THEN 
		
	ALTER TABLE assegni ADD  "id_mov_contabile" integer DEFAULT NULL;

end if;



IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'sys_modulo'
        AND      CNAME = 'assegni' )) THEN 
		
	ALTER TABLE sys_modulo ADD assegni char(1) DEFAULT NULL;
	ALTER TABLE assegni ADD  FOREIGN KEY "fk_assegni_mov" ("id_mov_contabile" ) REFERENCES "dba"."mov_contabile" ON DELETE CASCADE  ;

end if;


IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'par_sistema'
        AND      CNAME = 'ctr_fido_salvataggio' )) THEN 
		
	ALTER TABLE par_sistema ADD ctr_fido_salvataggio char(1) DEFAULT NULL;
	ALTER TABLE par_sistema ADD pwd_fido_sblocco char(20) DEFAULT NULL;

end if;


IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'par_sistema'
        AND      CNAME = 'fido_includi_ordini' )) THEN 
		
	ALTER TABLE par_sistema ADD fido_includi_ordini char(1) DEFAULT NULL;

end if;


IF NOT(EXISTS(
        SELECT 1 
        FROM   SYS.SYSCOLUMNS
        WHERE  TNAME = 'par_sistema'
        AND      CNAME = 'uno_num_copie_etichette' )) THEN 
		
	ALTER TABLE par_sistema ADD uno_num_copie_etichette char(1) DEFAULT NULL;

end if;


///////////////////////////////////////////////////

/*Questa  l'ultima operazione dello script che aggiorna la tabella degli aggiornamenti*/
//DA ESEGUIRE IN TUTTI GLI SCRIPT


IF EXISTS(
        SELECT 1 
        FROM   SYS.SYSTABLE
        WHERE  TABLE_NAME = 'TMP_FATTURATO') THEN
	DROP TABLE TMP_FATTURATO;
end if; 


CREATE TABLE "dba"."tmp_fatturato" 
("cod_1" char(32) DEFAULT NULL, "des_1" char(80) DEFAULT NULL, "cod_2" char(32) DEFAULT NULL, 
"des_2" char(80) DEFAULT NULL, "cod_3" char(32) DEFAULT NULL, "des_3" char(80) DEFAULT NULL, 
"cod_4" char(32) DEFAULT NULL, "des_4" char(80) DEFAULT NULL, "imp_1" numeric(18,4) DEFAULT NULL, 
"imp_2" numeric(18,4) DEFAULT NULL, "cod_art" char(32) DEFAULT NULL, "des_art" char(80) DEFAULT NULL, 
"quantita" numeric(20,6) DEFAULT NULL, "peso_netto" numeric(20,6) DEFAULT NULL, 
"prezzo_netto" numeric(20,6) DEFAULT NULL, "num_progressivo" integer DEFAULT NULL, 
"data_registrazione" date DEFAULT NULL, "id_documento" integer DEFAULT NULL, "id_articolo" integer DEFAULT NULL, 
"id_tmp_fatturato" integer NOT NULL DEFAULT autoincrement, "segno_iva" integer DEFAULT NULL) ;


//////
IF NOT(EXISTS(
        SELECT 1 
   FROM   script
   WHERE  codice = '2_01_015' )) THEN

        insert into script (codice,note,eseguito)
        values ('2_01_015','Release 2_01_015  Cometa','S')
        ;

END IF
;

